Class: Google::Apis::DisplayvideoV2::Advertiser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single advertiser in Display & Video 360 (DV360).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Advertiser

Returns a new instance of Advertiser.



241
242
243
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_server_configGoogle::Apis::DisplayvideoV2::AdvertiserAdServerConfig

Ad server related settings of an advertiser. Corresponds to the JSON property adServerConfig



140
141
142
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 140

def ad_server_config
  @ad_server_config
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser. Assigned by the system. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


145
146
147
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 145

def advertiser_id
  @advertiser_id
end

#contains_eu_political_adsString

Optional. Whether this advertiser contains line items that serve European Union political ads. If this field is set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING, then the following will happen: * Any new line items created under this advertiser will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. * Any existing line items under this advertiser that do not have a set value be updated to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING within a day. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


156
157
158
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 156

def contains_eu_political_ads
  @contains_eu_political_ads
end

#creative_configGoogle::Apis::DisplayvideoV2::AdvertiserCreativeConfig

Creatives related settings of an advertiser. Corresponds to the JSON property creativeConfig



161
162
163
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 161

def creative_config
  @creative_config
end

#data_access_configGoogle::Apis::DisplayvideoV2::AdvertiserDataAccessConfig

Settings that control how advertiser related data may be accessed. Corresponds to the JSON property dataAccessConfig



166
167
168
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 166

def data_access_config
  @data_access_config
end

#default_business_nameString

Optional. The default business name for the advertiser. This is the value used by YouTube and Demand Gen ads under this advertiser if a business name is not provided. Corresponds to the JSON property defaultBusinessName

Returns:

  • (String)


173
174
175
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 173

def default_business_name
  @default_business_name
end

#default_logo_asset_idFixnum

Optional. The asset ID of the default logo image for the advertiser. This is the asset ID that will be used by YouTube and Demand ads under this advertiser if a logo asset is not provided. You must use advertisers.adAssets.upload to upload this asset using the API. Corresponds to the JSON property defaultLogoAssetId

Returns:

  • (Fixnum)


181
182
183
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 181

def default_logo_asset_id
  @default_logo_asset_id
end

#display_nameString

Required. The display name of the advertiser. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


187
188
189
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 187

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not insertion orders and line items of the advertiser can spend their budgets and bid on inventory. * Accepted values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_PAUSED and ENTITY_STATUS_SCHEDULED_FOR_DELETION. * If set to ENTITY_STATUS_SCHEDULED_FOR_DELETION, the advertiser will be deleted 30 days from when it was first scheduled for deletion. Corresponds to the JSON property entityStatus

Returns:

  • (String)


197
198
199
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 197

def entity_status
  @entity_status
end

#general_configGoogle::Apis::DisplayvideoV2::AdvertiserGeneralConfig

General settings of an advertiser. Corresponds to the JSON property generalConfig



202
203
204
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 202

def general_config
  @general_config
end

#integration_detailsGoogle::Apis::DisplayvideoV2::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



207
208
209
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 207

def integration_details
  @integration_details
end

#nameString

Output only. The resource name of the advertiser. Corresponds to the JSON property name

Returns:

  • (String)


212
213
214
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 212

def name
  @name
end

#partner_idFixnum

Required. Immutable. The unique ID of the partner that the advertiser belongs to. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


218
219
220
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 218

def partner_id
  @partner_id
end

#prisma_enabledBoolean Also known as: prisma_enabled?

Whether integration with Mediaocean (Prisma) is enabled. By enabling this, you agree to the following: On behalf of my company, I authorize Mediaocean ( Prisma) to send budget segment plans to Google, and I authorize Google to send corresponding reporting and invoices from DV360 to Mediaocean for the purposes of budget planning, billing, and reconciliation for this advertiser. Corresponds to the JSON property prismaEnabled

Returns:

  • (Boolean)


227
228
229
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 227

def prisma_enabled
  @prisma_enabled
end

#serving_configGoogle::Apis::DisplayvideoV2::AdvertiserTargetingConfig

Targeting settings related to ad serving of an advertiser. Corresponds to the JSON property servingConfig



233
234
235
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 233

def serving_config
  @serving_config
end

#update_timeString

Output only. The timestamp when the advertiser was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


239
240
241
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 239

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 246

def update!(**args)
  @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @creative_config = args[:creative_config] if args.key?(:creative_config)
  @data_access_config = args[:data_access_config] if args.key?(:data_access_config)
  @default_business_name = args[:default_business_name] if args.key?(:default_business_name)
  @default_logo_asset_id = args[:default_logo_asset_id] if args.key?(:default_logo_asset_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @general_config = args[:general_config] if args.key?(:general_config)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @prisma_enabled = args[:prisma_enabled] if args.key?(:prisma_enabled)
  @serving_config = args[:serving_config] if args.key?(:serving_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end