Class: Google::Apis::DisplayvideoV2::AdvertiserSdfConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Structured Data Files (SDF) settings of an advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvertiserSdfConfig

Returns a new instance of AdvertiserSdfConfig.



440
441
442
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#override_partner_sdf_configBoolean Also known as: override_partner_sdf_config?

Whether or not this advertiser overrides the SDF configuration of its parent partner. By default, an advertiser inherits the SDF configuration from the parent partner. To override the partner configuration, set this field to true and provide the new configuration in sdfConfig. Corresponds to the JSON property overridePartnerSdfConfig

Returns:

  • (Boolean)


432
433
434
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 432

def override_partner_sdf_config
  @override_partner_sdf_config
end

#sdf_configGoogle::Apis::DisplayvideoV2::SdfConfig

Structured Data File (SDF) related settings. Corresponds to the JSON property sdfConfig



438
439
440
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 438

def sdf_config
  @sdf_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



445
446
447
448
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 445

def update!(**args)
  @override_partner_sdf_config = args[:override_partner_sdf_config] if args.key?(:override_partner_sdf_config)
  @sdf_config = args[:sdf_config] if args.key?(:sdf_config)
end