Class: Google::Apis::DisplayvideoV2::AppAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for assigned app targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_APP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppAssignedTargetingOptionDetails

Returns a new instance of AppAssignedTargetingOptionDetails.



548
549
550
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. The ID of the app. Android's Play store app uses bundle ID, for example com.google.android.gm. Apple's App store app ID uses 9 digit string, for example 422689480. Corresponds to the JSON property appId

Returns:

  • (String)


528
529
530
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 528

def app_id
  @app_id
end

#app_platformString

Indicates the platform of the targeted app. If this field is not specified, the app platform will be assumed to be mobile (i.e., Android or iOS), and we will derive the appropriate mobile platform from the app ID. Corresponds to the JSON property appPlatform

Returns:

  • (String)


535
536
537
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 535

def app_platform
  @app_platform
end

#display_nameString

Output only. The display name of the app. Corresponds to the JSON property displayName

Returns:

  • (String)


540
541
542
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 540

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. Corresponds to the JSON property negative

Returns:

  • (Boolean)


545
546
547
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 545

def negative
  @negative
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



553
554
555
556
557
558
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 553

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_platform = args[:app_platform] if args.key?(:app_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
end