Class: Google::Apis::DisplayvideoV2::AudioVideoOffset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

The length an audio or a video has been played.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AudioVideoOffset

Returns a new instance of AudioVideoOffset.



1359
1360
1361
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentageFixnum

Optional. The offset in percentage of the audio or video duration. Corresponds to the JSON property percentage

Returns:

  • (Fixnum)


1352
1353
1354
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1352

def percentage
  @percentage
end

#secondsFixnum

Optional. The offset in seconds from the start of the audio or video. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


1357
1358
1359
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1357

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1364
1365
1366
1367
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1364

def update!(**args)
  @percentage = args[:percentage] if args.key?(:percentage)
  @seconds = args[:seconds] if args.key?(:seconds)
end