Class: Google::Apis::DisplayvideoV2::BiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings that control the bid strategy. Bid strategy determines the bid price.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BiddingStrategy

Returns a new instance of BiddingStrategy.



1537
1538
1539
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#demand_gen_bidGoogle::Apis::DisplayvideoV2::DemandGenBiddingStrategy

Settings that control the bid strategy for Demand Gen resources. Corresponds to the JSON property demandGenBid



1518
1519
1520
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1518

def demand_gen_bid
  @demand_gen_bid
end

#fixed_bidGoogle::Apis::DisplayvideoV2::FixedBidStrategy

A strategy that uses a fixed bidding price. Corresponds to the JSON property fixedBid



1523
1524
1525
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1523

def fixed_bid
  @fixed_bid
end

#maximize_spend_auto_bidGoogle::Apis::DisplayvideoV2::MaximizeSpendBidStrategy

A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget. Corresponds to the JSON property maximizeSpendAutoBid



1529
1530
1531
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1529

def maximize_spend_auto_bid
  @maximize_spend_auto_bid
end

#performance_goal_auto_bidGoogle::Apis::DisplayvideoV2::PerformanceGoalBidStrategy

A strategy that automatically adjusts the bid to meet or beat a specified performance goal. Corresponds to the JSON property performanceGoalAutoBid



1535
1536
1537
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1535

def performance_goal_auto_bid
  @performance_goal_auto_bid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1542
1543
1544
1545
1546
1547
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1542

def update!(**args)
  @demand_gen_bid = args[:demand_gen_bid] if args.key?(:demand_gen_bid)
  @fixed_bid = args[:fixed_bid] if args.key?(:fixed_bid)
  @maximize_spend_auto_bid = args[:maximize_spend_auto_bid] if args.key?(:maximize_spend_auto_bid)
  @performance_goal_auto_bid = args[:performance_goal_auto_bid] if args.key?(:performance_goal_auto_bid)
end