Class: Google::Apis::DisplayvideoV2::BudgetSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Summarized information of an individual campaign budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BudgetSummary

Returns a new instance of BudgetSummary.



1643
1644
1645
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_budget_idString

Corresponds to the external_budget_id of a campaign budget. If the value is not set in the campaign budget, this field will be empty. Corresponds to the JSON property externalBudgetId

Returns:

  • (String)


1614
1615
1616
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1614

def external_budget_id
  @external_budget_id
end

#pre_tax_amount_microsFixnum

The sum of charges made under this budget before taxes, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property preTaxAmountMicros

Returns:

  • (Fixnum)


1621
1622
1623
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1621

def pre_tax_amount_micros
  @pre_tax_amount_micros
end

#prisma_cpe_codeGoogle::Apis::DisplayvideoV2::PrismaCpeCode

Google Payments Center supports searching and filtering on the component fields of this code. Corresponds to the JSON property prismaCpeCode



1627
1628
1629
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1627

def prisma_cpe_code
  @prisma_cpe_code
end

#tax_amount_microsFixnum

The amount of tax applied to charges under this budget, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property taxAmountMicros

Returns:

  • (Fixnum)


1634
1635
1636
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1634

def tax_amount_micros
  @tax_amount_micros
end

#total_amount_microsFixnum

The total sum of charges made under this budget, including tax, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


1641
1642
1643
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1641

def total_amount_micros
  @total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1648
1649
1650
1651
1652
1653
1654
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1648

def update!(**args)
  @external_budget_id = args[:external_budget_id] if args.key?(:external_budget_id)
  @pre_tax_amount_micros = args[:pre_tax_amount_micros] if args.key?(:pre_tax_amount_micros)
  @prisma_cpe_code = args[:prisma_cpe_code] if args.key?(:prisma_cpe_code)
  @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
end