Class: Google::Apis::DisplayvideoV2::BulkEditSitesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::BulkEditSitesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Request message for SiteService.BulkEditSites.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent channel.
-
#created_sites ⇒ Array<Google::Apis::DisplayvideoV2::Site>
The sites to create in batch, specified as a list of Sites.
-
#deleted_sites ⇒ Array<String>
The sites to delete in batch, specified as a list of site url_or_app_ids.
-
#partner_id ⇒ Fixnum
The ID of the partner that owns the parent channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditSitesRequest
constructor
A new instance of BulkEditSitesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditSitesRequest
Returns a new instance of BulkEditSitesRequest.
2100 2101 2102 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent channel.
Corresponds to the JSON property advertiserId
2083 2084 2085 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2083 def advertiser_id @advertiser_id end |
#created_sites ⇒ Array<Google::Apis::DisplayvideoV2::Site>
The sites to create in batch, specified as a list of Sites.
Corresponds to the JSON property createdSites
2088 2089 2090 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2088 def created_sites @created_sites end |
#deleted_sites ⇒ Array<String>
The sites to delete in batch, specified as a list of site url_or_app_ids.
Corresponds to the JSON property deletedSites
2093 2094 2095 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2093 def deleted_sites @deleted_sites end |
#partner_id ⇒ Fixnum
The ID of the partner that owns the parent channel.
Corresponds to the JSON property partnerId
2098 2099 2100 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2098 def partner_id @partner_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2105 2106 2107 2108 2109 2110 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2105 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @created_sites = args[:created_sites] if args.key?(:created_sites) @deleted_sites = args[:deleted_sites] if args.key?(:deleted_sites) @partner_id = args[:partner_id] if args.key?(:partner_id) end |