Class: Google::Apis::DisplayvideoV2::BusinessChainAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for assigned Business chain targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_BUSINESS_CHAIN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BusinessChainAssignedTargetingOptionDetails

Returns a new instance of BusinessChainAssignedTargetingOptionDetails.



2336
2337
2338
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of a business chain, e.g. "KFC", "Chase Bank". Corresponds to the JSON property displayName

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2312

def display_name
  @display_name
end

#proximity_radius_amountFloat

Required. The radius of the area around the business chain that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is DISTANCE_UNIT_MILES. The minimum increment for both cases is 0.1. Inputs will be rounded to the nearest acceptable value if it is too granular, e.g. 15.57 will become 15.6. Corresponds to the JSON property proximityRadiusAmount

Returns:

  • (Float)


2322
2323
2324
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2322

def proximity_radius_amount
  @proximity_radius_amount
end

#proximity_radius_unitString

Required. The unit of distance by which the targeting radius is measured. Corresponds to the JSON property proximityRadiusUnit

Returns:

  • (String)


2327
2328
2329
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2327

def proximity_radius_unit
  @proximity_radius_unit
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_BUSINESS_CHAIN. Accepted business chain targeting option IDs can be retrieved using SearchTargetingOptions. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


2334
2335
2336
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2334

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2341
2342
2343
2344
2345
2346
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2341

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @proximity_radius_amount = args[:proximity_radius_amount] if args.key?(:proximity_radius_amount)
  @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end