Class: Google::Apis::DisplayvideoV2::CarrierAndIspAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for assigned carrier and ISP targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_CARRIER_AND_ISP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarrierAndIspAssignedTargetingOptionDetails

Returns a new instance of CarrierAndIspAssignedTargetingOptionDetails.



2654
2655
2656
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the carrier or ISP. Corresponds to the JSON property displayName

Returns:

  • (String)


2638
2639
2640
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2638

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned carrier and ISP targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


2645
2646
2647
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2645

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_CARRIER_AND_ISP. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


2652
2653
2654
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2652

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2659
2660
2661
2662
2663
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2659

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end