Class: Google::Apis::DisplayvideoV2::Channel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single channel. Channels are custom groups of related websites and apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Channel

Returns a new instance of Channel.



2790
2791
2792
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser that owns the channel. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


2755
2756
2757
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2755

def advertiser_id
  @advertiser_id
end

#channel_idFixnum

Output only. The unique ID of the channel. Assigned by the system. Corresponds to the JSON property channelId

Returns:

  • (Fixnum)


2760
2761
2762
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2760

def channel_id
  @channel_id
end

#display_nameString

Required. The display name of the channel. Must be UTF-8 encoded with a maximum length of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


2766
2767
2768
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2766

def display_name
  @display_name
end

#nameString

Output only. The resource name of the channel. Corresponds to the JSON property name

Returns:

  • (String)


2771
2772
2773
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2771

def name
  @name
end

#negatively_targeted_line_item_countFixnum

Output only. Number of line items that are directly targeting this channel negatively. Corresponds to the JSON property negativelyTargetedLineItemCount

Returns:

  • (Fixnum)


2777
2778
2779
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2777

def negatively_targeted_line_item_count
  @negatively_targeted_line_item_count
end

#partner_idFixnum

The ID of the partner that owns the channel. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


2782
2783
2784
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2782

def partner_id
  @partner_id
end

#positively_targeted_line_item_countFixnum

Output only. Number of line items that are directly targeting this channel positively. Corresponds to the JSON property positivelyTargetedLineItemCount

Returns:

  • (Fixnum)


2788
2789
2790
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2788

def positively_targeted_line_item_count
  @positively_targeted_line_item_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2795
2796
2797
2798
2799
2800
2801
2802
2803
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2795

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @negatively_targeted_line_item_count = args[:negatively_targeted_line_item_count] if args.key?(:negatively_targeted_line_item_count)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @positively_targeted_line_item_count = args[:positively_targeted_line_item_count] if args.key?(:positively_targeted_line_item_count)
end