Class: Google::Apis::DisplayvideoV2::CommonInStreamAttribute
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::CommonInStreamAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Common attributes for in-stream, non-skippable and bumper ads.
Instance Attribute Summary collapse
-
#action_button_label ⇒ String
The text on the call-to-action button.
-
#action_headline ⇒ String
The headline of the call-to-action banner.
-
#companion_banner ⇒ Google::Apis::DisplayvideoV2::ImageAsset
Meta data of an image asset.
-
#display_url ⇒ String
The webpage address that appears with the ad.
-
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
-
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
-
#video ⇒ Google::Apis::DisplayvideoV2::YoutubeVideoDetails
Details of a YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommonInStreamAttribute
constructor
A new instance of CommonInStreamAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommonInStreamAttribute
Returns a new instance of CommonInStreamAttribute.
3048 3049 3050 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_button_label ⇒ String
The text on the call-to-action button.
Corresponds to the JSON property actionButtonLabel
3016 3017 3018 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3016 def @action_button_label end |
#action_headline ⇒ String
The headline of the call-to-action banner.
Corresponds to the JSON property actionHeadline
3021 3022 3023 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3021 def action_headline @action_headline end |
#companion_banner ⇒ Google::Apis::DisplayvideoV2::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property companionBanner
3026 3027 3028 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3026 def @companion_banner end |
#display_url ⇒ String
The webpage address that appears with the ad.
Corresponds to the JSON property displayUrl
3031 3032 3033 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3031 def display_url @display_url end |
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
Corresponds to the JSON property finalUrl
3036 3037 3038 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3036 def final_url @final_url end |
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
3041 3042 3043 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3041 def tracking_url @tracking_url end |
#video ⇒ Google::Apis::DisplayvideoV2::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
3046 3047 3048 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3046 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3053 3054 3055 3056 3057 3058 3059 3060 3061 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3053 def update!(**args) @action_button_label = args[:action_button_label] if args.key?(:action_button_label) @action_headline = args[:action_headline] if args.key?(:action_headline) @companion_banner = args[:companion_banner] if args.key?(:companion_banner) @display_url = args[:display_url] if args.key?(:display_url) @final_url = args[:final_url] if args.key?(:final_url) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @video = args[:video] if args.key?(:video) end |