Class: Google::Apis::DisplayvideoV2::ContentInstreamPositionAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Assigned content instream position targeting option details. This will be populated in the content_instream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentInstreamPositionAssignedTargetingOptionDetails

Returns a new instance of ContentInstreamPositionAssignedTargetingOptionDetails.



3211
3212
3213
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_typeString

Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * AD_TYPE_VIDEO, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_VIDEO_DEFAULT. * AD_TYPE_AUDIO, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_AUDIO_DEFAULT. Corresponds to the JSON property adType

Returns:

  • (String)


3204
3205
3206
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3204

def ad_type
  @ad_type
end

#content_instream_positionString

Required. The content instream position for video or audio ads. Corresponds to the JSON property contentInstreamPosition

Returns:

  • (String)


3209
3210
3211
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3209

def content_instream_position
  @content_instream_position
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3216
3217
3218
3219
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3216

def update!(**args)
  @ad_type = args[:ad_type] if args.key?(:ad_type)
  @content_instream_position = args[:content_instream_position] if args.key?(:content_instream_position)
end