Class: Google::Apis::DisplayvideoV2::CreateSdfDownloadTaskRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Request message for [SdfDownloadTaskService.CreateSdfDownloadTask].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateSdfDownloadTaskRequest

Returns a new instance of CreateSdfDownloadTaskRequest.



3522
3523
3524
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser to download SDF for. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


3491
3492
3493
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3491

def advertiser_id
  @advertiser_id
end

#id_filterGoogle::Apis::DisplayvideoV2::IdFilter

A filtering option that filters entities by their entity IDs. Corresponds to the JSON property idFilter



3496
3497
3498
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3496

def id_filter
  @id_filter
end

#inventory_source_filterGoogle::Apis::DisplayvideoV2::InventorySourceFilter

A filtering option for filtering on Inventory Source entities. Corresponds to the JSON property inventorySourceFilter



3501
3502
3503
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3501

def inventory_source_filter
  @inventory_source_filter
end

#parent_entity_filterGoogle::Apis::DisplayvideoV2::ParentEntityFilter

A filtering option that filters on selected file types belonging to a chosen set of filter entities. Corresponds to the JSON property parentEntityFilter



3507
3508
3509
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3507

def parent_entity_filter
  @parent_entity_filter
end

#partner_idFixnum

The ID of the partner to download SDF for. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


3512
3513
3514
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3512

def partner_id
  @partner_id
end

#versionString

Required. The SDF version of the downloaded file. If set to SDF_VERSION_UNSPECIFIED, this will default to the version specified by the advertiser or partner identified by root_id. An advertiser inherits its SDF version from its partner unless configured otherwise. Corresponds to the JSON property version

Returns:

  • (String)


3520
3521
3522
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3520

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3527

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @id_filter = args[:id_filter] if args.key?(:id_filter)
  @inventory_source_filter = args[:inventory_source_filter] if args.key?(:inventory_source_filter)
  @parent_entity_filter = args[:parent_entity_filter] if args.key?(:parent_entity_filter)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @version = args[:version] if args.key?(:version)
end