Class: Google::Apis::DisplayvideoV2::Creative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single Creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Creative

Returns a new instance of Creative.



3902
3903
3904
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_dimensionsArray<Google::Apis::DisplayvideoV2::Dimensions>

Optional. Additional dimensions. Applicable when creative_type is one of: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE * CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE * CREATIVE_TYPE_LIGHTBOX * CREATIVE_TYPE_PUBLISHER_HOSTED If this field is specified, width_pixels and height_pixels are both required and must be greater than or equal to 0. Corresponds to the JSON property additionalDimensions



3548
3549
3550
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3548

def additional_dimensions
  @additional_dimensions
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser the creative belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


3553
3554
3555
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3553

def advertiser_id
  @advertiser_id
end

#appended_tagString

Optional. Third-party HTML tracking tag to be appended to the creative tag. Corresponds to the JSON property appendedTag

Returns:

  • (String)


3558
3559
3560
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3558

def appended_tag
  @appended_tag
end

#assetsArray<Google::Apis::DisplayvideoV2::AssetAssociation>

Required. Assets associated to this creative. Corresponds to the JSON property assets



3563
3564
3565
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3563

def assets
  @assets
end

#cm_placement_idFixnum

Output only. The unique ID of the Campaign Manager 360 placement associated with the creative. This field is only applicable for creatives that are synced from Campaign Manager. Corresponds to the JSON property cmPlacementId

Returns:

  • (Fixnum)


3570
3571
3572
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3570

def cm_placement_id
  @cm_placement_id
end

#cm_tracking_adGoogle::Apis::DisplayvideoV2::CmTrackingAd

A Campaign Manager 360 tracking ad. Corresponds to the JSON property cmTrackingAd



3575
3576
3577
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3575

def cm_tracking_ad
  @cm_tracking_ad
end

#companion_creative_idsArray<Fixnum>

Optional. The IDs of companion creatives for a video creative. You can assign existing display creatives (with image or HTML5 assets) to serve surrounding the publisher's video player. Companions display around the video player while the video is playing and remain after the video has completed. Creatives contain additional dimensions can not be companion creatives. This field is only supported for the following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO Corresponds to the JSON property companionCreativeIds

Returns:

  • (Array<Fixnum>)


3586
3587
3588
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3586

def companion_creative_ids
  @companion_creative_ids
end

#counter_eventsArray<Google::Apis::DisplayvideoV2::CounterEvent>

Optional. Counter events for a rich media creative. Counters track the number of times that a user interacts with any part of a rich media creative in a specified way (mouse-overs, mouse-outs, clicks, taps, data loading, keyboard entries, etc.). Any event that can be captured in the creative can be recorded as a counter. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property counterEvents



3596
3597
3598
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3596

def counter_events
  @counter_events
end

#create_timeString

Output only. The timestamp when the creative was created. Assigned by the system. Corresponds to the JSON property createTime

Returns:

  • (String)


3602
3603
3604
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3602

def create_time
  @create_time
end

#creative_attributesArray<String>

Output only. A list of attributes of the creative that is generated by the system. Corresponds to the JSON property creativeAttributes

Returns:

  • (Array<String>)


3608
3609
3610
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3608

def creative_attributes
  @creative_attributes
end

#creative_idFixnum

Output only. The unique ID of the creative. Assigned by the system. Corresponds to the JSON property creativeId

Returns:

  • (Fixnum)


3613
3614
3615
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3613

def creative_id
  @creative_id
end

#creative_typeString

Required. Immutable. The type of the creative. Corresponds to the JSON property creativeType

Returns:

  • (String)


3618
3619
3620
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3618

def creative_type
  @creative_type
end

#dimensionsGoogle::Apis::DisplayvideoV2::Dimensions

Dimensions. Corresponds to the JSON property dimensions



3623
3624
3625
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3623

def dimensions
  @dimensions
end

#display_nameString

Required. The display name of the creative. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


3629
3630
3631
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3629

def display_name
  @display_name
end

#dynamicBoolean Also known as: dynamic?

Output only. Indicates whether the creative is dynamic. Corresponds to the JSON property dynamic

Returns:

  • (Boolean)


3634
3635
3636
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3634

def dynamic
  @dynamic
end

#entity_statusString

Required. Controls whether or not the creative can serve. Accepted values are:

  • ENTITY_STATUS_ACTIVE * ENTITY_STATUS_ARCHIVED * ENTITY_STATUS_PAUSED Corresponds to the JSON property entityStatus

Returns:

  • (String)


3641
3642
3643
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3641

def entity_status
  @entity_status
end

#exit_eventsArray<Google::Apis::DisplayvideoV2::ExitEvent>

Required. Exit events for this creative. An exit (also known as a click tag) is any area in your creative that someone can click or tap to open an advertiser's landing page. Every creative must include at least one exit. You can add an exit to your creative in any of the following ways: * Use Google Web Designer's tap area. * Define a JavaScript variable called "clickTag". * Use the Enabler (Enabler.exit()) to track exits in rich media formats. Corresponds to the JSON property exitEvents



3651
3652
3653
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3651

def exit_events
  @exit_events
end

#expand_on_hoverBoolean Also known as: expand_on_hover?

Optional. Indicates the creative will automatically expand on hover. Optional and only valid for third-party expandable creatives. Third-party expandable creatives are creatives with following hosting source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property expandOnHover

Returns:

  • (Boolean)


3660
3661
3662
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3660

def expand_on_hover
  @expand_on_hover
end

#expanding_directionString

Optional. Specifies the expanding direction of the creative. Required and only valid for third-party expandable creatives. Third-party expandable creatives are creatives with following hosting source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property expandingDirection

Returns:

  • (String)


3669
3670
3671
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3669

def expanding_direction
  @expanding_direction
end

#hosting_sourceString

Required. Indicates where the creative is hosted. Corresponds to the JSON property hostingSource

Returns:

  • (String)


3674
3675
3676
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3674

def hosting_source
  @hosting_source
end

#html5_videoBoolean Also known as: html5_video?

Output only. Indicates the third-party VAST tag creative requires HTML5 Video support. Output only and only valid for third-party VAST tag creatives. Third- party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_VIDEO Corresponds to the JSON property html5Video

Returns:

  • (Boolean)


3683
3684
3685
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3683

def html5_video
  @html5_video
end

#ias_campaign_monitoringBoolean Also known as: ias_campaign_monitoring?

Optional. Indicates whether Integral Ad Science (IAS) campaign monitoring is enabled. To enable this for the creative, make sure the Advertiser. creative_config.ias_client_id has been set to your IAS client ID. Corresponds to the JSON property iasCampaignMonitoring

Returns:

  • (Boolean)


3691
3692
3693
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3691

def ias_campaign_monitoring
  @ias_campaign_monitoring
end

#integration_codeString

Optional. ID information used to link this creative to an external system. Must be UTF-8 encoded with a length of no more than 10,000 characters. Corresponds to the JSON property integrationCode

Returns:

  • (String)


3698
3699
3700
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3698

def integration_code
  @integration_code
end

#js_tracker_urlString

Optional. JavaScript measurement URL from supported third-party verification providers (ComScore, DoubleVerify, IAS, Moat). HTML script tags are not supported. This field is only writeable in the following creative_type: * CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE * CREATIVE_TYPE_NATIVE_VIDEO Corresponds to the JSON property jsTrackerUrl

Returns:

  • (String)


3707
3708
3709
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3707

def js_tracker_url
  @js_tracker_url
end

#line_item_idsArray<Fixnum>

Output only. The IDs of the line items this creative is associated with. To associate a creative to a line item, use LineItem.creative_ids instead. Corresponds to the JSON property lineItemIds

Returns:

  • (Array<Fixnum>)


3713
3714
3715
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3713

def line_item_ids
  @line_item_ids
end

#media_durationString

Output only. Media duration of the creative. Applicable when creative_type is one of: * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_NATIVE_VIDEO * CREATIVE_TYPE_PUBLISHER_HOSTED Corresponds to the JSON property mediaDuration

Returns:

  • (String)


3720
3721
3722
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3720

def media_duration
  @media_duration
end

#mp3_audioBoolean Also known as: mp3_audio?

Output only. Indicates the third-party audio creative supports MP3. Output only and only valid for third-party audio creatives. Third-party audio creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO Corresponds to the JSON property mp3Audio

Returns:

  • (Boolean)


3729
3730
3731
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3729

def mp3_audio
  @mp3_audio
end

#nameString

Output only. The resource name of the creative. Corresponds to the JSON property name

Returns:

  • (String)


3735
3736
3737
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3735

def name
  @name
end

#notesString

Optional. User notes for this creative. Must be UTF-8 encoded with a length of no more than 20,000 characters. Corresponds to the JSON property notes

Returns:

  • (String)


3741
3742
3743
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3741

def notes
  @notes
end

#oba_iconGoogle::Apis::DisplayvideoV2::ObaIcon

OBA Icon for a Creative Corresponds to the JSON property obaIcon



3746
3747
3748
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3746

def oba_icon
  @oba_icon
end

#ogg_audioBoolean Also known as: ogg_audio?

Output only. Indicates the third-party audio creative supports OGG. Output only and only valid for third-party audio creatives. Third-party audio creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO Corresponds to the JSON property oggAudio

Returns:

  • (Boolean)


3755
3756
3757
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3755

def ogg_audio
  @ogg_audio
end

#progress_offsetGoogle::Apis::DisplayvideoV2::AudioVideoOffset

The length an audio or a video has been played. Corresponds to the JSON property progressOffset



3761
3762
3763
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3761

def progress_offset
  @progress_offset
end

#require_html5Boolean Also known as: require_html5?

Optional. Indicates that the creative relies on HTML5 to render properly. Optional and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property requireHtml5

Returns:

  • (Boolean)


3770
3771
3772
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3770

def require_html5
  @require_html5
end

#require_mraidBoolean Also known as: require_mraid?

Optional. Indicates that the creative requires MRAID (Mobile Rich Media Ad Interface Definitions system). Set this if the creative relies on mobile gestures for interactivity, such as swiping or tapping. Optional and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property requireMraid

Returns:

  • (Boolean)


3782
3783
3784
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3782

def require_mraid
  @require_mraid
end

#require_ping_for_attributionBoolean Also known as: require_ping_for_attribution?

Optional. Indicates that the creative will wait for a return ping for attribution. Only valid when using a Campaign Manager 360 tracking ad with a third-party ad server parameter and the $DC_DBM_TOKEN macro. Optional and only valid for third-party tag creatives or third-party VAST tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Third-party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO Corresponds to the JSON property requirePingForAttribution

Returns:

  • (Boolean)


3797
3798
3799
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3797

def require_ping_for_attribution
  @require_ping_for_attribution
end

#review_statusGoogle::Apis::DisplayvideoV2::ReviewStatusInfo

Review statuses for the creative. Corresponds to the JSON property reviewStatus



3803
3804
3805
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3803

def review_status
  @review_status
end

#skip_offsetGoogle::Apis::DisplayvideoV2::AudioVideoOffset

The length an audio or a video has been played. Corresponds to the JSON property skipOffset



3808
3809
3810
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3808

def skip_offset
  @skip_offset
end

#skippableBoolean Also known as: skippable?

Optional. Whether the user can choose to skip a video creative. This field is only supported for the following creative_type: * CREATIVE_TYPE_VIDEO Corresponds to the JSON property skippable

Returns:

  • (Boolean)


3814
3815
3816
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3814

def skippable
  @skippable
end

#synthetic_content_attestation_statusString

Optional. Whether the creative contains synthetic content or was created using AI. Corresponds to the JSON property syntheticContentAttestationStatus

Returns:

  • (String)


3821
3822
3823
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3821

def synthetic_content_attestation_status
  @synthetic_content_attestation_status
end

#third_party_tagString

Optional. The original third-party tag used for the creative. Required and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property thirdPartyTag

Returns:

  • (String)


3830
3831
3832
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3830

def third_party_tag
  @third_party_tag
end

#third_party_urlsArray<Google::Apis::DisplayvideoV2::ThirdPartyUrl>

Optional. Tracking URLs from third parties to track interactions with a video creative. This field is only supported for the following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_NATIVE_VIDEO Corresponds to the JSON property thirdPartyUrls



3837
3838
3839
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3837

def third_party_urls
  @third_party_urls
end

#timer_eventsArray<Google::Apis::DisplayvideoV2::TimerEvent>

Optional. Timer custom events for a rich media creative. Timers track the time during which a user views and interacts with a specified part of a rich media creative. A creative can have multiple timer events, each timed independently. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property timerEvents



3845
3846
3847
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3845

def timer_events
  @timer_events
end

#tracker_urlsArray<String>

Optional. Tracking URLs for analytics providers or third-party ad technology vendors. The URLs must start with https: (except on inventory that doesn't require SSL compliance). If using macros in your URL, use only macros supported by Display & Video 360. Standard URLs only, no IMG or SCRIPT tags. This field is only writeable in the following creative_type: * CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE * CREATIVE_TYPE_NATIVE_VIDEO Corresponds to the JSON property trackerUrls

Returns:

  • (Array<String>)


3856
3857
3858
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3856

def tracker_urls
  @tracker_urls
end

#transcodesArray<Google::Apis::DisplayvideoV2::Transcode>

Output only. Audio/Video transcodes. Display & Video 360 transcodes the main asset into a number of alternative versions that use different file formats or have different properties (resolution, audio bit rate, and video bit rate), each designed for specific video players or bandwidths. These transcodes give a publisher's system more options to choose from for each impression on your video and ensures that the appropriate file serves based on the viewer’s connection and screen size. This field is only supported in the following creative_type: * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_NATIVE_VIDEO * CREATIVE_TYPE_AUDIO Corresponds to the JSON property transcodes



3869
3870
3871
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3869

def transcodes
  @transcodes
end

#universal_ad_idGoogle::Apis::DisplayvideoV2::UniversalAdId

A creative identifier provided by a registry that is unique across all platforms. This is part of the VAST 4.0 standard. Corresponds to the JSON property universalAdId



3875
3876
3877
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3875

def universal_ad_id
  @universal_ad_id
end

#update_timeString

Output only. The timestamp when the creative was last updated, either by the user or system (e.g. creative review). Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


3881
3882
3883
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3881

def update_time
  @update_time
end

#vast_tag_urlString

Optional. The URL of the VAST tag for a third-party VAST tag creative. Required and only valid for third-party VAST tag creatives. Third-party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO Corresponds to the JSON property vastTagUrl

Returns:

  • (String)


3890
3891
3892
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3890

def vast_tag_url
  @vast_tag_url
end

#vpaidBoolean Also known as: vpaid?

Output only. Indicates the third-party VAST tag creative requires VPAID ( Digital Video Player-Ad Interface). Output only and only valid for third-party VAST tag creatives. Third-party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_VIDEO Corresponds to the JSON property vpaid

Returns:

  • (Boolean)


3899
3900
3901
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3899

def vpaid
  @vpaid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3907
3908
3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
3925
3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3907

def update!(**args)
  @additional_dimensions = args[:additional_dimensions] if args.key?(:additional_dimensions)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @appended_tag = args[:appended_tag] if args.key?(:appended_tag)
  @assets = args[:assets] if args.key?(:assets)
  @cm_placement_id = args[:cm_placement_id] if args.key?(:cm_placement_id)
  @cm_tracking_ad = args[:cm_tracking_ad] if args.key?(:cm_tracking_ad)
  @companion_creative_ids = args[:companion_creative_ids] if args.key?(:companion_creative_ids)
  @counter_events = args[:counter_events] if args.key?(:counter_events)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creative_attributes = args[:creative_attributes] if args.key?(:creative_attributes)
  @creative_id = args[:creative_id] if args.key?(:creative_id)
  @creative_type = args[:creative_type] if args.key?(:creative_type)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @dynamic = args[:dynamic] if args.key?(:dynamic)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exit_events = args[:exit_events] if args.key?(:exit_events)
  @expand_on_hover = args[:expand_on_hover] if args.key?(:expand_on_hover)
  @expanding_direction = args[:expanding_direction] if args.key?(:expanding_direction)
  @hosting_source = args[:hosting_source] if args.key?(:hosting_source)
  @html5_video = args[:html5_video] if args.key?(:html5_video)
  @ias_campaign_monitoring = args[:ias_campaign_monitoring] if args.key?(:ias_campaign_monitoring)
  @integration_code = args[:integration_code] if args.key?(:integration_code)
  @js_tracker_url = args[:js_tracker_url] if args.key?(:js_tracker_url)
  @line_item_ids = args[:line_item_ids] if args.key?(:line_item_ids)
  @media_duration = args[:media_duration] if args.key?(:media_duration)
  @mp3_audio = args[:mp3_audio] if args.key?(:mp3_audio)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @oba_icon = args[:oba_icon] if args.key?(:oba_icon)
  @ogg_audio = args[:ogg_audio] if args.key?(:ogg_audio)
  @progress_offset = args[:progress_offset] if args.key?(:progress_offset)
  @require_html5 = args[:require_html5] if args.key?(:require_html5)
  @require_mraid = args[:require_mraid] if args.key?(:require_mraid)
  @require_ping_for_attribution = args[:require_ping_for_attribution] if args.key?(:require_ping_for_attribution)
  @review_status = args[:review_status] if args.key?(:review_status)
  @skip_offset = args[:skip_offset] if args.key?(:skip_offset)
  @skippable = args[:skippable] if args.key?(:skippable)
  @synthetic_content_attestation_status = args[:synthetic_content_attestation_status] if args.key?(:synthetic_content_attestation_status)
  @third_party_tag = args[:third_party_tag] if args.key?(:third_party_tag)
  @third_party_urls = args[:third_party_urls] if args.key?(:third_party_urls)
  @timer_events = args[:timer_events] if args.key?(:timer_events)
  @tracker_urls = args[:tracker_urls] if args.key?(:tracker_urls)
  @transcodes = args[:transcodes] if args.key?(:transcodes)
  @universal_ad_id = args[:universal_ad_id] if args.key?(:universal_ad_id)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vast_tag_url = args[:vast_tag_url] if args.key?(:vast_tag_url)
  @vpaid = args[:vpaid] if args.key?(:vpaid)
end