Class: Google::Apis::DisplayvideoV2::CustomBiddingAlgorithm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single custom bidding algorithm.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingAlgorithm

Returns a new instance of CustomBiddingAlgorithm.



3994
3995
3996
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Immutable. The unique ID of the advertiser that owns the custom bidding algorithm. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


3936
3937
3938
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3936

def advertiser_id
  @advertiser_id
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm. Assigned by the system. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


3942
3943
3944
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3942

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_algorithm_typeString

Required. Immutable. The type of custom bidding algorithm. Corresponds to the JSON property customBiddingAlgorithmType

Returns:

  • (String)


3947
3948
3949
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3947

def custom_bidding_algorithm_type
  @custom_bidding_algorithm_type
end

#display_nameString

Required. The display name of the custom bidding algorithm. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


3953
3954
3955
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3953

def display_name
  @display_name
end

#entity_statusString

Controls whether or not the custom bidding algorithm can be used as a bidding strategy. Accepted values are: * ENTITY_STATUS_ACTIVE * ENTITY_STATUS_ARCHIVED Corresponds to the JSON property entityStatus

Returns:

  • (String)


3960
3961
3962
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3960

def entity_status
  @entity_status
end

#model_detailsArray<Google::Apis::DisplayvideoV2::CustomBiddingModelDetails>

Output only. The details of custom bidding models for each advertiser who has access. This field may only include the details of the queried advertiser if the algorithm owner is a partner and is being retrieved using an advertiser accessor. Corresponds to the JSON property modelDetails



3971
3972
3973
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3971

def model_details
  @model_details
end

#nameString

Output only. The resource name of the custom bidding algorithm. Corresponds to the JSON property name

Returns:

  • (String)


3976
3977
3978
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3976

def name
  @name
end

#partner_idFixnum

Immutable. The unique ID of the partner that owns the custom bidding algorithm. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


3981
3982
3983
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3981

def partner_id
  @partner_id
end

#shared_advertiser_idsArray<Fixnum>

The IDs of the advertisers who have access to this algorithm. If advertiser_id is set, this field will only consist of that value. This field will not be set if the algorithm owner is a partner and is being retrieved using an advertiser accessor. Corresponds to the JSON property sharedAdvertiserIds

Returns:

  • (Array<Fixnum>)


3992
3993
3994
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3992

def shared_advertiser_ids
  @shared_advertiser_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3999

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_algorithm_type = args[:custom_bidding_algorithm_type] if args.key?(:custom_bidding_algorithm_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @model_details = args[:model_details] if args.key?(:model_details)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids)
end