Class: Google::Apis::DisplayvideoV2::CustomBiddingScript
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::CustomBiddingScript
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
A single custom bidding script.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_script_id ⇒ Fixnum
Output only.
-
#errors ⇒ Array<Google::Apis::DisplayvideoV2::ScriptError>
Output only.
-
#name ⇒ String
Output only.
-
#script ⇒ Google::Apis::DisplayvideoV2::CustomBiddingScriptRef
The reference to the uploaded custom bidding script file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingScript
constructor
A new instance of CustomBiddingScript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingScript
Returns a new instance of CustomBiddingScript.
4100 4101 4102 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Output only. Whether the script is currently being used for scoring by the
parent algorithm.
Corresponds to the JSON property active
4060 4061 4062 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4060 def active @active end |
#create_time ⇒ String
Output only. The time when the script was created.
Corresponds to the JSON property createTime
4066 4067 4068 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4066 def create_time @create_time end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm the script belongs
to.
Corresponds to the JSON property customBiddingAlgorithmId
4072 4073 4074 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4072 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_script_id ⇒ Fixnum
Output only. The unique ID of the custom bidding script.
Corresponds to the JSON property customBiddingScriptId
4077 4078 4079 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4077 def custom_bidding_script_id @custom_bidding_script_id end |
#errors ⇒ Array<Google::Apis::DisplayvideoV2::ScriptError>
Output only. Error details of a rejected custom bidding script. This field
will only be populated when state is REJECTED.
Corresponds to the JSON property errors
4083 4084 4085 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4083 def errors @errors end |
#name ⇒ String
Output only. The resource name of the custom bidding script.
Corresponds to the JSON property name
4088 4089 4090 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4088 def name @name end |
#script ⇒ Google::Apis::DisplayvideoV2::CustomBiddingScriptRef
The reference to the uploaded custom bidding script file.
Corresponds to the JSON property script
4093 4094 4095 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4093 def script @script end |
#state ⇒ String
Output only. The state of the custom bidding script.
Corresponds to the JSON property state
4098 4099 4100 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4098 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4105 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id) @errors = args[:errors] if args.key?(:errors) @name = args[:name] if args.key?(:name) @script = args[:script] if args.key?(:script) @state = args[:state] if args.key?(:state) end |