Class: Google::Apis::DisplayvideoV2::GuaranteedOrder
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::GuaranteedOrder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
A guaranteed order. Guaranteed orders are parent entity of guaranteed inventory sources. When creating a guaranteed inventory source, a guaranteed order ID must be assigned to the inventory source.
Instance Attribute Summary collapse
-
#default_advertiser_id ⇒ Fixnum
Output only.
-
#default_campaign_id ⇒ Fixnum
The ID of the default campaign that is assigned to the guaranteed order.
-
#display_name ⇒ String
Required.
-
#exchange ⇒ String
Required.
-
#guaranteed_order_id ⇒ String
Output only.
-
#legacy_guaranteed_order_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#publisher_name ⇒ String
Required.
-
#read_access_inherited ⇒ Boolean
(also: #read_access_inherited?)
Whether all advertisers of read_write_partner_id have read access to the guaranteed order.
-
#read_advertiser_ids ⇒ Array<Fixnum>
The IDs of advertisers with read access to the guaranteed order.
-
#read_write_advertiser_id ⇒ Fixnum
The advertiser with read/write access to the guaranteed order.
-
#read_write_partner_id ⇒ Fixnum
The partner with read/write access to the guaranteed order.
-
#status ⇒ Google::Apis::DisplayvideoV2::GuaranteedOrderStatus
The status settings of the guaranteed order.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuaranteedOrder
constructor
A new instance of GuaranteedOrder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuaranteedOrder
Returns a new instance of GuaranteedOrder.
5777 5778 5779 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_advertiser_id ⇒ Fixnum
Output only. The ID of default advertiser of the guaranteed order. The default
advertiser is either the read_write_advertiser_id or, if that is not set, the
first advertiser listed in read_advertiser_ids. Otherwise, there is no default
advertiser.
Corresponds to the JSON property defaultAdvertiserId
5696 5697 5698 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5696 def default_advertiser_id @default_advertiser_id end |
#default_campaign_id ⇒ Fixnum
The ID of the default campaign that is assigned to the guaranteed order. The
default campaign must belong to the default advertiser.
Corresponds to the JSON property defaultCampaignId
5702 5703 5704 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5702 def default_campaign_id @default_campaign_id end |
#display_name ⇒ String
Required. The display name of the guaranteed order. Must be UTF-8 encoded with
a maximum size of 240 bytes.
Corresponds to the JSON property displayName
5708 5709 5710 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5708 def display_name @display_name end |
#exchange ⇒ String
Required. Immutable. The exchange where the guaranteed order originated.
Corresponds to the JSON property exchange
5713 5714 5715 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5713 def exchange @exchange end |
#guaranteed_order_id ⇒ String
Output only. The unique identifier of the guaranteed order. The guaranteed
order IDs have the format exchange`-`legacy_guaranteed_order_id.
Corresponds to the JSON property guaranteedOrderId
5719 5720 5721 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5719 def guaranteed_order_id @guaranteed_order_id end |
#legacy_guaranteed_order_id ⇒ String
Output only. The legacy ID of the guaranteed order. Assigned by the original
exchange. The legacy ID is unique within one exchange, but is not guaranteed
to be unique across all guaranteed orders. This ID is used in SDF and UI.
Corresponds to the JSON property legacyGuaranteedOrderId
5726 5727 5728 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5726 def legacy_guaranteed_order_id @legacy_guaranteed_order_id end |
#name ⇒ String
Output only. The resource name of the guaranteed order.
Corresponds to the JSON property name
5731 5732 5733 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5731 def name @name end |
#publisher_name ⇒ String
Required. The publisher name of the guaranteed order. Must be UTF-8 encoded
with a maximum size of 240 bytes.
Corresponds to the JSON property publisherName
5737 5738 5739 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5737 def publisher_name @publisher_name end |
#read_access_inherited ⇒ Boolean Also known as: read_access_inherited?
Whether all advertisers of read_write_partner_id have read access to the
guaranteed order. Only applicable if read_write_partner_id is set. If True,
overrides read_advertiser_ids.
Corresponds to the JSON property readAccessInherited
5744 5745 5746 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5744 def read_access_inherited @read_access_inherited end |
#read_advertiser_ids ⇒ Array<Fixnum>
The IDs of advertisers with read access to the guaranteed order. This field
must not include the advertiser assigned to read_write_advertiser_id if it is
set. All advertisers in this field must belong to read_write_partner_id or the
same partner as read_write_advertiser_id.
Corresponds to the JSON property readAdvertiserIds
5753 5754 5755 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5753 def read_advertiser_ids @read_advertiser_ids end |
#read_write_advertiser_id ⇒ Fixnum
The advertiser with read/write access to the guaranteed order. This is also
the default advertiser of the guaranteed order.
Corresponds to the JSON property readWriteAdvertiserId
5759 5760 5761 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5759 def read_write_advertiser_id @read_write_advertiser_id end |
#read_write_partner_id ⇒ Fixnum
The partner with read/write access to the guaranteed order.
Corresponds to the JSON property readWritePartnerId
5764 5765 5766 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5764 def read_write_partner_id @read_write_partner_id end |
#status ⇒ Google::Apis::DisplayvideoV2::GuaranteedOrderStatus
The status settings of the guaranteed order.
Corresponds to the JSON property status
5769 5770 5771 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5769 def status @status end |
#update_time ⇒ String
Output only. The timestamp when the guaranteed order was last updated.
Assigned by the system.
Corresponds to the JSON property updateTime
5775 5776 5777 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5775 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5782 5783 5784 5785 5786 5787 5788 5789 5790 5791 5792 5793 5794 5795 5796 5797 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5782 def update!(**args) @default_advertiser_id = args[:default_advertiser_id] if args.key?(:default_advertiser_id) @default_campaign_id = args[:default_campaign_id] if args.key?(:default_campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @exchange = args[:exchange] if args.key?(:exchange) @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id) @legacy_guaranteed_order_id = args[:legacy_guaranteed_order_id] if args.key?(:legacy_guaranteed_order_id) @name = args[:name] if args.key?(:name) @publisher_name = args[:publisher_name] if args.key?(:publisher_name) @read_access_inherited = args[:read_access_inherited] if args.key?(:read_access_inherited) @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids) @read_write_advertiser_id = args[:read_write_advertiser_id] if args.key?(:read_write_advertiser_id) @read_write_partner_id = args[:read_write_partner_id] if args.key?(:read_write_partner_id) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) end |