Class: Google::Apis::DisplayvideoV2::LanguageAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for assigned language targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_LANGUAGE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageAssignedTargetingOptionDetails

Returns a new instance of LanguageAssignedTargetingOptionDetails.



6641
6642
6643
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the language (e.g., "French"). Corresponds to the JSON property displayName

Returns:

  • (String)


6626
6627
6628
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6626

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned language targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


6632
6633
6634
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6632

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


6639
6640
6641
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6639

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6646
6647
6648
6649
6650
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6646

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end