Class: Google::Apis::DisplayvideoV2::ListCampaignsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::ListCampaignsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Instance Attribute Summary collapse
-
#campaigns ⇒ Array<Google::Apis::DisplayvideoV2::Campaign>
The list of campaigns.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCampaignsResponse
constructor
A new instance of ListCampaignsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCampaignsResponse
Returns a new instance of ListCampaignsResponse.
7101 7102 7103 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaigns ⇒ Array<Google::Apis::DisplayvideoV2::Campaign>
The list of campaigns. This list will be absent if empty.
Corresponds to the JSON property campaigns
7092 7093 7094 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7092 def campaigns @campaigns end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCampaigns method to retrieve
the next page of results.
Corresponds to the JSON property nextPageToken
7099 7100 7101 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7099 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7106 7107 7108 7109 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7106 def update!(**args) @campaigns = args[:campaigns] if args.key?(:campaigns) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |