Class: Google::Apis::DisplayvideoV2::ListCreativesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCreativesResponse

Returns a new instance of ListCreativesResponse.



7214
7215
7216
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creativesArray<Google::Apis::DisplayvideoV2::Creative>

The list of creatives. This list will be absent if empty. Corresponds to the JSON property creatives



7204
7205
7206
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7204

def creatives
  @creatives
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCreativesRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7212
7213
7214
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7212

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7219
7220
7221
7222
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7219

def update!(**args)
  @creatives = args[:creatives] if args.key?(:creatives)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end