Class: Google::Apis::DisplayvideoV2::ListCustomBiddingAlgorithmsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCustomBiddingAlgorithmsResponse

Returns a new instance of ListCustomBiddingAlgorithmsResponse.



7242
7243
7244
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_bidding_algorithmsArray<Google::Apis::DisplayvideoV2::CustomBiddingAlgorithm>

The list of custom bidding algorithms. This list will be absent if empty. Corresponds to the JSON property customBiddingAlgorithms



7232
7233
7234
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7232

def custom_bidding_algorithms
  @custom_bidding_algorithms
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCustomBiddingAlgorithmsRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7240
7241
7242
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7240

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7247
7248
7249
7250
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7247

def update!(**args)
  @custom_bidding_algorithms = args[:custom_bidding_algorithms] if args.key?(:custom_bidding_algorithms)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end