Class: Google::Apis::DisplayvideoV2::ListFloodlightActivitiesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFloodlightActivitiesResponse

Returns a new instance of ListFloodlightActivitiesResponse.



7324
7325
7326
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activitiesArray<Google::Apis::DisplayvideoV2::FloodlightActivity>

The list of Floodlight activities. This list will be absent if empty. Corresponds to the JSON property floodlightActivities



7315
7316
7317
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7315

def floodlight_activities
  @floodlight_activities
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListFloodlightActivities method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7322
7323
7324
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7322

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7329
7330
7331
7332
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7329

def update!(**args)
  @floodlight_activities = args[:floodlight_activities] if args.key?(:floodlight_activities)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end