Class: Google::Apis::DisplayvideoV2::ListInvoicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInvoicesResponse

Returns a new instance of ListInvoicesResponse.



7460
7461
7462
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#invoicesArray<Google::Apis::DisplayvideoV2::Invoice>

The list of invoices. This list will be absent if empty. Corresponds to the JSON property invoices



7450
7451
7452
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7450

def invoices
  @invoices
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListInvoices method to retrieve the next page of results. This token will be absent if there are no more invoices to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7458
7459
7460
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7458

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7465
7466
7467
7468
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7465

def update!(**args)
  @invoices = args[:invoices] if args.key?(:invoices)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end