Class: Google::Apis::DisplayvideoV2::ListYoutubeAdGroupAdsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::ListYoutubeAdGroupAdsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#youtube_ad_group_ads ⇒ Array<Google::Apis::DisplayvideoV2::YoutubeAdGroupAd>
The list of ad group ads.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListYoutubeAdGroupAdsResponse
constructor
A new instance of ListYoutubeAdGroupAdsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListYoutubeAdGroupAdsResponse
Returns a new instance of ListYoutubeAdGroupAdsResponse.
7787 7788 7789 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListYoutubeAdGroupAds method to
retrieve the next page of results.
Corresponds to the JSON property nextPageToken
7780 7781 7782 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7780 def next_page_token @next_page_token end |
#youtube_ad_group_ads ⇒ Array<Google::Apis::DisplayvideoV2::YoutubeAdGroupAd>
The list of ad group ads. This list will be absent if empty.
Corresponds to the JSON property youtubeAdGroupAds
7785 7786 7787 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7785 def youtube_ad_group_ads @youtube_ad_group_ads end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7792 7793 7794 7795 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7792 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @youtube_ad_group_ads = args[:youtube_ad_group_ads] if args.key?(:youtube_ad_group_ads) end |