Class: Google::Apis::DisplayvideoV2::ListYoutubeAdGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListYoutubeAdGroupsResponse

Returns a new instance of ListYoutubeAdGroupsResponse.



7812
7813
7814
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListYoutubeAdGroups method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7805
7806
7807
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7805

def next_page_token
  @next_page_token
end

#youtube_ad_groupsArray<Google::Apis::DisplayvideoV2::YoutubeAdGroup>

The list of ad groups. This list will be absent if empty. Corresponds to the JSON property youtubeAdGroups



7810
7811
7812
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7810

def youtube_ad_groups
  @youtube_ad_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7817
7818
7819
7820
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7817

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @youtube_ad_groups = args[:youtube_ad_groups] if args.key?(:youtube_ad_groups)
end