Class: Google::Apis::DisplayvideoV2::ManualTrigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single manual trigger in Display & Video 360. Warning: Line Items using manual triggers no longer serve in Display & Video 360. This resource will sunset on August 1, 2023. Read our feature deprecation announcement for more information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManualTrigger

Returns a new instance of ManualTrigger.



7994
7995
7996
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_duration_minutesFixnum

Required. The maximum duration of each activation in minutes. Must be between 1 and 360 inclusive. After this duration, the trigger will be automatically deactivated. Corresponds to the JSON property activationDurationMinutes

Returns:

  • (Fixnum)


7959
7960
7961
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7959

def activation_duration_minutes
  @activation_duration_minutes
end

#advertiser_idFixnum

Required. Immutable. The unique ID of the advertiser that the manual trigger belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7965
7966
7967
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7965

def advertiser_id
  @advertiser_id
end

#display_nameString

Required. The display name of the manual trigger. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


7971
7972
7973
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7971

def display_name
  @display_name
end

#latest_activation_timeString

Output only. The timestamp of the trigger's latest activation. Corresponds to the JSON property latestActivationTime

Returns:

  • (String)


7976
7977
7978
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7976

def latest_activation_time
  @latest_activation_time
end

#nameString

Output only. The resource name of the manual trigger. Corresponds to the JSON property name

Returns:

  • (String)


7981
7982
7983
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7981

def name
  @name
end

#stateString

Output only. The state of the manual trigger. Will be set to the INACTIVE state upon creation. Corresponds to the JSON property state

Returns:

  • (String)


7987
7988
7989
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7987

def state
  @state
end

#trigger_idFixnum

Output only. The unique ID of the manual trigger. Corresponds to the JSON property triggerId

Returns:

  • (Fixnum)


7992
7993
7994
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7992

def trigger_id
  @trigger_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7999
8000
8001
8002
8003
8004
8005
8006
8007
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7999

def update!(**args)
  @activation_duration_minutes = args[:activation_duration_minutes] if args.key?(:activation_duration_minutes)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @latest_activation_time = args[:latest_activation_time] if args.key?(:latest_activation_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @trigger_id = args[:trigger_id] if args.key?(:trigger_id)
end