Class: Google::Apis::DisplayvideoV2::MastheadAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::MastheadAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Details for a Masthead Ad.
Instance Attribute Summary collapse
-
#autoplay_video_duration ⇒ String
The duration of time the video will autoplay.
-
#autoplay_video_start_millisecond ⇒ Fixnum
The amount of time in milliseconds after which the video will start to play.
-
#call_to_action_button_label ⇒ String
The text on the call-to-action button.
-
#call_to_action_final_url ⇒ String
The destination URL for the call-to-action button.
-
#call_to_action_tracking_url ⇒ String
The tracking URL for the call-to-action button.
-
#companion_youtube_videos ⇒ Array<Google::Apis::DisplayvideoV2::YoutubeVideoDetails>
The videos that appear next to the Masthead Ad on desktop.
-
#description ⇒ String
The description of the ad.
-
#headline ⇒ String
The headline of the ad.
-
#show_channel_art ⇒ Boolean
(also: #show_channel_art?)
Whether to show a background or banner that appears at the top of a YouTube page.
-
#video ⇒ Google::Apis::DisplayvideoV2::YoutubeVideoDetails
Details of a YouTube video.
-
#video_aspect_ratio ⇒ String
The aspect ratio of the autoplaying YouTube video on the Masthead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MastheadAd
constructor
A new instance of MastheadAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MastheadAd
Returns a new instance of MastheadAd.
8048 8049 8050 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoplay_video_duration ⇒ String
The duration of time the video will autoplay.
Corresponds to the JSON property autoplayVideoDuration
7993 7994 7995 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7993 def autoplay_video_duration @autoplay_video_duration end |
#autoplay_video_start_millisecond ⇒ Fixnum
The amount of time in milliseconds after which the video will start to play.
Corresponds to the JSON property autoplayVideoStartMillisecond
7998 7999 8000 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7998 def autoplay_video_start_millisecond @autoplay_video_start_millisecond end |
#call_to_action_button_label ⇒ String
The text on the call-to-action button.
Corresponds to the JSON property callToActionButtonLabel
8003 8004 8005 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8003 def @call_to_action_button_label end |
#call_to_action_final_url ⇒ String
The destination URL for the call-to-action button.
Corresponds to the JSON property callToActionFinalUrl
8008 8009 8010 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8008 def call_to_action_final_url @call_to_action_final_url end |
#call_to_action_tracking_url ⇒ String
The tracking URL for the call-to-action button.
Corresponds to the JSON property callToActionTrackingUrl
8013 8014 8015 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8013 def call_to_action_tracking_url @call_to_action_tracking_url end |
#companion_youtube_videos ⇒ Array<Google::Apis::DisplayvideoV2::YoutubeVideoDetails>
The videos that appear next to the Masthead Ad on desktop. Can be no more than
two.
Corresponds to the JSON property companionYoutubeVideos
8019 8020 8021 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8019 def companion_youtube_videos @companion_youtube_videos end |
#description ⇒ String
The description of the ad.
Corresponds to the JSON property description
8024 8025 8026 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8024 def description @description end |
#headline ⇒ String
The headline of the ad.
Corresponds to the JSON property headline
8029 8030 8031 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8029 def headline @headline end |
#show_channel_art ⇒ Boolean Also known as: show_channel_art?
Whether to show a background or banner that appears at the top of a YouTube
page.
Corresponds to the JSON property showChannelArt
8035 8036 8037 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8035 def show_channel_art @show_channel_art end |
#video ⇒ Google::Apis::DisplayvideoV2::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
8041 8042 8043 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8041 def video @video end |
#video_aspect_ratio ⇒ String
The aspect ratio of the autoplaying YouTube video on the Masthead.
Corresponds to the JSON property videoAspectRatio
8046 8047 8048 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8046 def video_aspect_ratio @video_aspect_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8053 8054 8055 8056 8057 8058 8059 8060 8061 8062 8063 8064 8065 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8053 def update!(**args) @autoplay_video_duration = args[:autoplay_video_duration] if args.key?(:autoplay_video_duration) @autoplay_video_start_millisecond = args[:autoplay_video_start_millisecond] if args.key?(:autoplay_video_start_millisecond) @call_to_action_button_label = args[:call_to_action_button_label] if args.key?(:call_to_action_button_label) @call_to_action_final_url = args[:call_to_action_final_url] if args.key?(:call_to_action_final_url) @call_to_action_tracking_url = args[:call_to_action_tracking_url] if args.key?(:call_to_action_tracking_url) @companion_youtube_videos = args[:companion_youtube_videos] if args.key?(:companion_youtube_videos) @description = args[:description] if args.key?(:description) @headline = args[:headline] if args.key?(:headline) @show_channel_art = args[:show_channel_art] if args.key?(:show_channel_art) @video = args[:video] if args.key?(:video) @video_aspect_ratio = args[:video_aspect_ratio] if args.key?(:video_aspect_ratio) end |