Class: Google::Apis::DisplayvideoV2::MobileApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A mobile app promoted by a mobile app install line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileApp

Returns a new instance of MobileApp.



8194
8195
8196
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. The ID of the app provided by the platform store. Android apps are identified by the bundle ID used by Android's Play store, such as com.google. android.gm. iOS apps are identified by a nine-digit app ID used by Apple's App store, such as 422689480. Corresponds to the JSON property appId

Returns:

  • (String)


8177
8178
8179
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8177

def app_id
  @app_id
end

#display_nameString

Output only. The app name. Corresponds to the JSON property displayName

Returns:

  • (String)


8182
8183
8184
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8182

def display_name
  @display_name
end

#platformString

Output only. The app platform. Corresponds to the JSON property platform

Returns:

  • (String)


8187
8188
8189
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8187

def platform
  @platform
end

#publisherString

Output only. The app publisher. Corresponds to the JSON property publisher

Returns:

  • (String)


8192
8193
8194
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8192

def publisher
  @publisher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8199
8200
8201
8202
8203
8204
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8199

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @platform = args[:platform] if args.key?(:platform)
  @publisher = args[:publisher] if args.key?(:publisher)
end