Class: Google::Apis::DisplayvideoV2::NonSkippableAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::NonSkippableAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Details for a non-skippable ad.
Instance Attribute Summary collapse
-
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV2::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
-
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NonSkippableAd
constructor
A new instance of NonSkippableAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NonSkippableAd
Returns a new instance of NonSkippableAd.
8333 8334 8335 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV2::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
Corresponds to the JSON property commonInStreamAttribute
8326 8327 8328 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8326 def common_in_stream_attribute @common_in_stream_attribute end |
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Corresponds to the JSON property customParameters
8331 8332 8333 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8331 def custom_parameters @custom_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8338 8339 8340 8341 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8338 def update!(**args) @common_in_stream_attribute = args[:common_in_stream_attribute] if args.key?(:common_in_stream_attribute) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) end |