Class: Google::Apis::DisplayvideoV2::PoiAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for assigned POI targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_POI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PoiAssignedTargetingOptionDetails

Returns a new instance of PoiAssignedTargetingOptionDetails.



9179
9180
9181
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of a POI, e.g. "Times Square", "Space Needle", followed by its full address if available. Corresponds to the JSON property displayName

Returns:

  • (String)


9139
9140
9141
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9139

def display_name
  @display_name
end

#latitudeFloat

Output only. Latitude of the POI rounding to 6th decimal place. Corresponds to the JSON property latitude

Returns:

  • (Float)


9144
9145
9146
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9144

def latitude
  @latitude
end

#longitudeFloat

Output only. Longitude of the POI rounding to 6th decimal place. Corresponds to the JSON property longitude

Returns:

  • (Float)


9149
9150
9151
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9149

def longitude
  @longitude
end

#proximity_radius_amountFloat

Required. The radius of the area around the POI that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is DISTANCE_UNIT_MILES. Corresponds to the JSON property proximityRadiusAmount

Returns:

  • (Float)


9157
9158
9159
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9157

def proximity_radius_amount
  @proximity_radius_amount
end

#proximity_radius_unitString

Required. The unit of distance by which the targeting radius is measured. Corresponds to the JSON property proximityRadiusUnit

Returns:

  • (String)


9162
9163
9164
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9162

def proximity_radius_unit
  @proximity_radius_unit
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_POI. Accepted POI targeting option IDs can be retrieved using targetingTypes.targetingOptions.search. If targeting a specific latitude/ longitude coordinate removed from an address or POI name, you can generate the necessary targeting option ID by rounding the desired coordinate values to the 6th decimal place, removing the decimals, and concatenating the string values separated by a semicolon. For example, you can target the latitude/longitude pair of 40.7414691, -74.003387 using the targeting option ID "40741469;- 74003387". Upon creation, this field value will be updated to append a semicolon and alphanumerical hash value if only latitude/longitude coordinates are provided. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


9177
9178
9179
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9177

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9184
9185
9186
9187
9188
9189
9190
9191
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9184

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
  @proximity_radius_amount = args[:proximity_radius_amount] if args.key?(:proximity_radius_amount)
  @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end