Class: Google::Apis::DisplayvideoV2::ReplaceSitesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Request message for SiteService.ReplaceSites.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplaceSitesRequest

Returns a new instance of ReplaceSitesRequest.



9517
9518
9519
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser that owns the parent channel. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


9504
9505
9506
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9504

def advertiser_id
  @advertiser_id
end

#new_sitesArray<Google::Apis::DisplayvideoV2::Site>

The sites that will replace the existing sites assigned to the channel, specified as a list of Sites. Corresponds to the JSON property newSites



9510
9511
9512
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9510

def new_sites
  @new_sites
end

#partner_idFixnum

The ID of the partner that owns the parent channel. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


9515
9516
9517
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9515

def partner_id
  @partner_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9522
9523
9524
9525
9526
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9522

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @new_sites = args[:new_sites] if args.key?(:new_sites)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
end