Class: Google::Apis::DisplayvideoV2::ReviewStatusInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Review statuses for the creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReviewStatusInfo

Returns a new instance of ReviewStatusInfo.



9579
9580
9581
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_statusString

Represents the basic approval needed for a creative to begin serving. Summary of creative_and_landing_page_review_status and content_and_policy_review_status. Corresponds to the JSON property approvalStatus

Returns:

  • (String)


9557
9558
9559
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9557

def approval_status
  @approval_status
end

#content_and_policy_review_statusString

Content and policy review status for the creative. Corresponds to the JSON property contentAndPolicyReviewStatus

Returns:

  • (String)


9562
9563
9564
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9562

def content_and_policy_review_status
  @content_and_policy_review_status
end

#creative_and_landing_page_review_statusString

Creative and landing page review status for the creative. Corresponds to the JSON property creativeAndLandingPageReviewStatus

Returns:

  • (String)


9567
9568
9569
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9567

def creative_and_landing_page_review_status
  @creative_and_landing_page_review_status
end

#exchange_review_statusesArray<Google::Apis::DisplayvideoV2::ExchangeReviewStatus>

Exchange review statuses for the creative. Corresponds to the JSON property exchangeReviewStatuses



9572
9573
9574
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9572

def exchange_review_statuses
  @exchange_review_statuses
end

#publisher_review_statusesArray<Google::Apis::DisplayvideoV2::PublisherReviewStatus>

Publisher review statuses for the creative. Corresponds to the JSON property publisherReviewStatuses



9577
9578
9579
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9577

def publisher_review_statuses
  @publisher_review_statuses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9584
9585
9586
9587
9588
9589
9590
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9584

def update!(**args)
  @approval_status = args[:approval_status] if args.key?(:approval_status)
  @content_and_policy_review_status = args[:content_and_policy_review_status] if args.key?(:content_and_policy_review_status)
  @creative_and_landing_page_review_status = args[:creative_and_landing_page_review_status] if args.key?(:creative_and_landing_page_review_status)
  @exchange_review_statuses = args[:exchange_review_statuses] if args.key?(:exchange_review_statuses)
  @publisher_review_statuses = args[:publisher_review_statuses] if args.key?(:publisher_review_statuses)
end