Class: Google::Apis::DisplayvideoV2::ScriptError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

An error message for a custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScriptError

Returns a new instance of ScriptError.



9617
9618
9619
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnFixnum

The column number in the script where the error was thrown. Corresponds to the JSON property column

Returns:

  • (Fixnum)


9600
9601
9602
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9600

def column
  @column
end

#error_codeString

The type of error. Corresponds to the JSON property errorCode

Returns:

  • (String)


9605
9606
9607
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9605

def error_code
  @error_code
end

#error_messageString

The detailed error message. Corresponds to the JSON property errorMessage

Returns:

  • (String)


9610
9611
9612
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9610

def error_message
  @error_message
end

#lineFixnum

The line number in the script where the error was thrown. Corresponds to the JSON property line

Returns:

  • (Fixnum)


9615
9616
9617
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9615

def line
  @line
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9622
9623
9624
9625
9626
9627
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9622

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @line = args[:line] if args.key?(:line)
end