Class: Google::Apis::DisplayvideoV2::SearchTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Request message for SearchTargetingOptions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchTargetingOptionsRequest

Returns a new instance of SearchTargetingOptionsRequest.



9758
9759
9760
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Required. The Advertiser this request is being made in the context of. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


9725
9726
9727
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9725

def advertiser_id
  @advertiser_id
end

#business_chain_search_termsGoogle::Apis::DisplayvideoV2::BusinessChainSearchTerms

Search terms for Business Chain targeting options. At least one of the field should be populated. Corresponds to the JSON property businessChainSearchTerms



9731
9732
9733
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9731

def business_chain_search_terms
  @business_chain_search_terms
end

#geo_region_search_termsGoogle::Apis::DisplayvideoV2::GeoRegionSearchTerms

Search terms for geo region targeting options. Corresponds to the JSON property geoRegionSearchTerms



9736
9737
9738
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9736

def geo_region_search_terms
  @geo_region_search_terms
end

#page_sizeFixnum

Requested page size. Must be between 1 and 200. If unspecified will default to 100. Returns error code INVALID_ARGUMENT if an invalid value is specified. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


9743
9744
9745
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9743

def page_size
  @page_size
end

#page_tokenString

A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to SearchTargetingOptions method. If not specified, the first page of results will be returned. Corresponds to the JSON property pageToken

Returns:

  • (String)


9751
9752
9753
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9751

def page_token
  @page_token
end

#poi_search_termsGoogle::Apis::DisplayvideoV2::PoiSearchTerms

Search terms for POI targeting options. Corresponds to the JSON property poiSearchTerms



9756
9757
9758
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9756

def poi_search_terms
  @poi_search_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 9763

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @business_chain_search_terms = args[:business_chain_search_terms] if args.key?(:business_chain_search_terms)
  @geo_region_search_terms = args[:geo_region_search_terms] if args.key?(:geo_region_search_terms)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @poi_search_terms = args[:poi_search_terms] if args.key?(:poi_search_terms)
end