Class: Google::Apis::DisplayvideoV2::TrackingFloodlightActivityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings that control the behavior of a single Floodlight activity config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackingFloodlightActivityConfig

Returns a new instance of TrackingFloodlightActivityConfig.



10577
10578
10579
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Required. The ID of the Floodlight activity. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


10563
10564
10565
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10563

def floodlight_activity_id
  @floodlight_activity_id
end

#post_click_lookback_window_daysFixnum

Required. The number of days after an ad has been clicked in which a conversion may be counted. Must be between 0 and 90 inclusive. Corresponds to the JSON property postClickLookbackWindowDays

Returns:

  • (Fixnum)


10569
10570
10571
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10569

def post_click_lookback_window_days
  @post_click_lookback_window_days
end

#post_view_lookback_window_daysFixnum

Required. The number of days after an ad has been viewed in which a conversion may be counted. Must be between 0 and 90 inclusive. Corresponds to the JSON property postViewLookbackWindowDays

Returns:

  • (Fixnum)


10575
10576
10577
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10575

def post_view_lookback_window_days
  @post_view_lookback_window_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10582
10583
10584
10585
10586
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10582

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @post_click_lookback_window_days = args[:post_click_lookback_window_days] if args.key?(:post_click_lookback_window_days)
  @post_view_lookback_window_days = args[:post_view_lookback_window_days] if args.key?(:post_view_lookback_window_days)
end