Class: Google::Apis::DisplayvideoV2::VideoAdSequenceStep
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::VideoAdSequenceStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
The detail of a single step in a VideoAdSequence.
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
The ID of the corresponding ad group of the step.
-
#interaction_type ⇒ String
The interaction on the previous step that will lead the viewer to this step.
-
#previous_step_id ⇒ Fixnum
The ID of the previous step.
-
#step_id ⇒ Fixnum
The ID of the step.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoAdSequenceStep
constructor
A new instance of VideoAdSequenceStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoAdSequenceStep
Returns a new instance of VideoAdSequenceStep.
10879 10880 10881 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
The ID of the corresponding ad group of the step.
Corresponds to the JSON property adGroupId
10861 10862 10863 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10861 def ad_group_id @ad_group_id end |
#interaction_type ⇒ String
The interaction on the previous step that will lead the viewer to this step.
The first step does not have interaction_type.
Corresponds to the JSON property interactionType
10867 10868 10869 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10867 def interaction_type @interaction_type end |
#previous_step_id ⇒ Fixnum
The ID of the previous step. The first step does not have previous step.
Corresponds to the JSON property previousStepId
10872 10873 10874 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10872 def previous_step_id @previous_step_id end |
#step_id ⇒ Fixnum
The ID of the step.
Corresponds to the JSON property stepId
10877 10878 10879 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10877 def step_id @step_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10884 10885 10886 10887 10888 10889 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10884 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @previous_step_id = args[:previous_step_id] if args.key?(:previous_step_id) @step_id = args[:step_id] if args.key?(:step_id) end |