Class: Google::Apis::DisplayvideoV2::VideoPerformanceAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for a video performance ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPerformanceAd

Returns a new instance of VideoPerformanceAd.



10999
11000
11001
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelsArray<String>

The list of text assets shown on the call-to-action button. Corresponds to the JSON property actionButtonLabels

Returns:

  • (Array<String>)


10942
10943
10944
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10942

def action_button_labels
  @action_button_labels
end

#companion_bannersArray<Google::Apis::DisplayvideoV2::ImageAsset>

The list of companion banners used by this ad. Corresponds to the JSON property companionBanners



10947
10948
10949
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10947

def companion_banners
  @companion_banners
end

#custom_parametersHash<String,String>

The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


10952
10953
10954
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10952

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

The list of descriptions shown on the call-to-action banner. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


10957
10958
10959
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10957

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


10962
10963
10964
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10962

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


10967
10968
10969
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10967

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#domainString

The domain of the display URL. Corresponds to the JSON property domain

Returns:

  • (String)


10972
10973
10974
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10972

def domain
  @domain
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


10977
10978
10979
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10977

def final_url
  @final_url
end

#headlinesArray<String>

The list of headlines shown on the call-to-action banner. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


10982
10983
10984
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10982

def headlines
  @headlines
end

#long_headlinesArray<String>

The list of long headlines shown on the call-to-action banner. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


10987
10988
10989
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10987

def long_headlines
  @long_headlines
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


10992
10993
10994
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10992

def tracking_url
  @tracking_url
end

#videosArray<Google::Apis::DisplayvideoV2::YoutubeVideoDetails>

The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



10997
10998
10999
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10997

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11004
11005
11006
11007
11008
11009
11010
11011
11012
11013
11014
11015
11016
11017
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11004

def update!(**args)
  @action_button_labels = args[:action_button_labels] if args.key?(:action_button_labels)
  @companion_banners = args[:companion_banners] if args.key?(:companion_banners)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @domain = args[:domain] if args.key?(:domain)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headlines = args[:headlines] if args.key?(:headlines)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end