Class: Google::Apis::DisplayvideoV2::YoutubeAdGroupAssignedTargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Wrapper object associating an AssignedTargetingOption resource and the youtube ad group it is assigned to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAdGroupAssignedTargetingOption

Returns a new instance of YoutubeAdGroupAssignedTargetingOption.



11318
11319
11320
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_targeting_optionGoogle::Apis::DisplayvideoV2::AssignedTargetingOption

A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings. Corresponds to the JSON property assignedTargetingOption



11311
11312
11313
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11311

def assigned_targeting_option
  @assigned_targeting_option
end

#youtube_ad_group_idFixnum

The ID of the youtube ad group the assigned targeting option is assigned to. Corresponds to the JSON property youtubeAdGroupId

Returns:

  • (Fixnum)


11316
11317
11318
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11316

def youtube_ad_group_id
  @youtube_ad_group_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11323
11324
11325
11326
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11323

def update!(**args)
  @assigned_targeting_option = args[:assigned_targeting_option] if args.key?(:assigned_targeting_option)
  @youtube_ad_group_id = args[:youtube_ad_group_id] if args.key?(:youtube_ad_group_id)
end