Class: Google::Apis::DisplayvideoV2::YoutubeAndPartnersInventorySourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings that control what YouTube related inventories the YouTube and Partners line item will target.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAndPartnersInventorySourceConfig

Returns a new instance of YoutubeAndPartnersInventorySourceConfig.



11410
11411
11412
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_google_tvBoolean Also known as: include_google_tv?

Optional. Whether to target inventory in video apps available with Google TV. Corresponds to the JSON property includeGoogleTv

Returns:

  • (Boolean)


11387
11388
11389
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11387

def include_google_tv
  @include_google_tv
end

#include_youtube_searchBoolean Also known as: include_youtube_search?

Whether to target inventory on the YouTube search results page. Corresponds to the JSON property includeYoutubeSearch

Returns:

  • (Boolean)


11393
11394
11395
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11393

def include_youtube_search
  @include_youtube_search
end

#include_youtube_video_partnersBoolean Also known as: include_youtube_video_partners?

Whether to target inventory on a collection of partner sites and apps that follow the same brand safety standards as YouTube. Corresponds to the JSON property includeYoutubeVideoPartners

Returns:

  • (Boolean)


11400
11401
11402
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11400

def include_youtube_video_partners
  @include_youtube_video_partners
end

#include_youtube_videosBoolean Also known as: include_youtube_videos?

Whether to target inventory of channels and videos on YouTube and YouTube videos embedded on other sites. Corresponds to the JSON property includeYoutubeVideos

Returns:

  • (Boolean)


11407
11408
11409
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11407

def include_youtube_videos
  @include_youtube_videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11415
11416
11417
11418
11419
11420
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11415

def update!(**args)
  @include_google_tv = args[:include_google_tv] if args.key?(:include_google_tv)
  @include_youtube_search = args[:include_youtube_search] if args.key?(:include_youtube_search)
  @include_youtube_video_partners = args[:include_youtube_video_partners] if args.key?(:include_youtube_video_partners)
  @include_youtube_videos = args[:include_youtube_videos] if args.key?(:include_youtube_videos)
end