Class: Google::Apis::DisplayvideoV2::YoutubeVideoDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::YoutubeVideoDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Details of a YouTube video.
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#unavailable_reason ⇒ String
The reason why the video data is not available.
-
#video_asset_id ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeVideoDetails
constructor
A new instance of YoutubeVideoDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeVideoDetails
Returns a new instance of YoutubeVideoDetails.
11634 11635 11636 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. The YouTube video ID which can be searched on YouTube webpage.
Corresponds to the JSON property id
11621 11622 11623 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11621 def id @id end |
#unavailable_reason ⇒ String
The reason why the video data is not available.
Corresponds to the JSON property unavailableReason
11626 11627 11628 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11626 def unavailable_reason @unavailable_reason end |
#video_asset_id ⇒ Fixnum
Required. The YouTube video asset id. This is the adAssetId of an AdAsset
resource.
Corresponds to the JSON property videoAssetId
11632 11633 11634 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11632 def video_asset_id @video_asset_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11639 11640 11641 11642 11643 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11639 def update!(**args) @id = args[:id] if args.key?(:id) @unavailable_reason = args[:unavailable_reason] if args.key?(:unavailable_reason) @video_asset_id = args[:video_asset_id] if args.key?(:video_asset_id) end |