Class: Google::Apis::DisplayvideoV2::AppAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::AppAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Details for assigned app targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_APP.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Required.
-
#app_platform ⇒ String
Indicates the platform of the targeted app.
-
#display_name ⇒ String
Output only.
-
#negative ⇒ Boolean
(also: #negative?)
Indicates if this option is being negatively targeted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppAssignedTargetingOptionDetails
constructor
A new instance of AppAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppAssignedTargetingOptionDetails
Returns a new instance of AppAssignedTargetingOptionDetails.
531 532 533 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Required. The ID of the app. Android's Play store app uses bundle ID, for
example com.google.android.gm. Apple's App store app ID uses 9 digit string,
for example 422689480.
Corresponds to the JSON property appId
511 512 513 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 511 def app_id @app_id end |
#app_platform ⇒ String
Indicates the platform of the targeted app. If this field is not specified,
the app platform will be assumed to be mobile (i.e., Android or iOS), and we
will derive the appropriate mobile platform from the app ID.
Corresponds to the JSON property appPlatform
518 519 520 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 518 def app_platform @app_platform end |
#display_name ⇒ String
Output only. The display name of the app.
Corresponds to the JSON property displayName
523 524 525 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 523 def display_name @display_name end |
#negative ⇒ Boolean Also known as: negative?
Indicates if this option is being negatively targeted.
Corresponds to the JSON property negative
528 529 530 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 528 def negative @negative end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
536 537 538 539 540 541 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 536 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @app_platform = args[:app_platform] if args.key?(:app_platform) @display_name = args[:display_name] if args.key?(:display_name) @negative = args[:negative] if args.key?(:negative) end |