Class: Google::Apis::DisplayvideoV2::BiddingStrategy
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::BiddingStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Settings that control the bid strategy. Bid strategy determines the bid price.
Instance Attribute Summary collapse
-
#demand_gen_bid ⇒ Google::Apis::DisplayvideoV2::DemandGenBiddingStrategy
Settings that control the bid strategy for Demand Gen resources.
-
#fixed_bid ⇒ Google::Apis::DisplayvideoV2::FixedBidStrategy
A strategy that uses a fixed bidding price.
-
#maximize_spend_auto_bid ⇒ Google::Apis::DisplayvideoV2::MaximizeSpendBidStrategy
A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget.
-
#performance_goal_auto_bid ⇒ Google::Apis::DisplayvideoV2::PerformanceGoalBidStrategy
A strategy that automatically adjusts the bid to meet or beat a specified performance goal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BiddingStrategy
constructor
A new instance of BiddingStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BiddingStrategy
Returns a new instance of BiddingStrategy.
1529 1530 1531 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#demand_gen_bid ⇒ Google::Apis::DisplayvideoV2::DemandGenBiddingStrategy
Settings that control the bid strategy for Demand Gen resources.
Corresponds to the JSON property demandGenBid
1510 1511 1512 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1510 def demand_gen_bid @demand_gen_bid end |
#fixed_bid ⇒ Google::Apis::DisplayvideoV2::FixedBidStrategy
A strategy that uses a fixed bidding price.
Corresponds to the JSON property fixedBid
1515 1516 1517 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1515 def fixed_bid @fixed_bid end |
#maximize_spend_auto_bid ⇒ Google::Apis::DisplayvideoV2::MaximizeSpendBidStrategy
A strategy that automatically adjusts the bid to optimize a specified
performance goal while spending the full budget.
Corresponds to the JSON property maximizeSpendAutoBid
1521 1522 1523 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1521 def maximize_spend_auto_bid @maximize_spend_auto_bid end |
#performance_goal_auto_bid ⇒ Google::Apis::DisplayvideoV2::PerformanceGoalBidStrategy
A strategy that automatically adjusts the bid to meet or beat a specified
performance goal.
Corresponds to the JSON property performanceGoalAutoBid
1527 1528 1529 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1527 def performance_goal_auto_bid @performance_goal_auto_bid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1534 1535 1536 1537 1538 1539 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 1534 def update!(**args) @demand_gen_bid = args[:demand_gen_bid] if args.key?(:demand_gen_bid) @fixed_bid = args[:fixed_bid] if args.key?(:fixed_bid) @maximize_spend_auto_bid = args[:maximize_spend_auto_bid] if args.key?(:maximize_spend_auto_bid) @performance_goal_auto_bid = args[:performance_goal_auto_bid] if args.key?(:performance_goal_auto_bid) end |