Class: Google::Apis::DisplayvideoV2::BulkListAdGroupAssignedTargetingOptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::BulkListAdGroupAssignedTargetingOptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying the next page of results.
-
#youtube_ad_group_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV2::YoutubeAdGroupAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and the youtube ad group it is assigned to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkListAdGroupAssignedTargetingOptionsResponse
constructor
A new instance of BulkListAdGroupAssignedTargetingOptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkListAdGroupAssignedTargetingOptionsResponse
Returns a new instance of BulkListAdGroupAssignedTargetingOptionsResponse.
2144 2145 2146 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying the next page of results. This value should be specified
as the pageToken in a subsequent call to
BulkListAdGroupAssignedTargetingOptions to fetch the next page of results.
This token will be absent if there are no more AdGroupAssignedTargetingOption
resources to return.
Corresponds to the JSON property nextPageToken
2136 2137 2138 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2136 def next_page_token @next_page_token end |
#youtube_ad_group_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV2::YoutubeAdGroupAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and
the youtube ad group it is assigned to. This list will be absent if empty.
Corresponds to the JSON property youtubeAdGroupAssignedTargetingOptions
2142 2143 2144 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2142 def @youtube_ad_group_assigned_targeting_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2149 2150 2151 2152 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2149 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @youtube_ad_group_assigned_targeting_options = args[:youtube_ad_group_assigned_targeting_options] if args.key?(:youtube_ad_group_assigned_targeting_options) end |