Class: Google::Apis::DisplayvideoV2::CampaignBudget
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::CampaignBudget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Settings that control how the campaign budget is allocated.
Instance Attribute Summary collapse
-
#budget_amount_micros ⇒ Fixnum
Required.
-
#budget_id ⇒ Fixnum
The unique ID of the campaign budget.
-
#budget_unit ⇒ String
Required.
-
#date_range ⇒ Google::Apis::DisplayvideoV2::DateRange
A date range.
-
#display_name ⇒ String
Required.
-
#external_budget_id ⇒ String
Immutable.
-
#external_budget_source ⇒ String
Required.
-
#invoice_grouping_id ⇒ String
Immutable.
-
#prisma_config ⇒ Google::Apis::DisplayvideoV2::PrismaConfig
Settings specific to the Mediaocean Prisma tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CampaignBudget
constructor
A new instance of CampaignBudget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CampaignBudget
Returns a new instance of CampaignBudget.
2558 2559 2560 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_amount_micros ⇒ Fixnum
Required. The total amount the linked insertion order segments can budget. The
amount is in micros. Must be greater than 0. For example, 500000000 represents
500 standard units of the currency.
Corresponds to the JSON property budgetAmountMicros
2506 2507 2508 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2506 def budget_amount_micros @budget_amount_micros end |
#budget_id ⇒ Fixnum
The unique ID of the campaign budget. Assigned by the system. Do not set for
new budgets. Must be included when updating or adding budgets to
campaign_budgets. Otherwise, a new ID will be generated and assigned.
Corresponds to the JSON property budgetId
2513 2514 2515 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2513 def budget_id @budget_id end |
#budget_unit ⇒ String
Required. Immutable. Specifies whether the budget is measured in currency or
impressions.
Corresponds to the JSON property budgetUnit
2519 2520 2521 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2519 def budget_unit @budget_unit end |
#date_range ⇒ Google::Apis::DisplayvideoV2::DateRange
A date range.
Corresponds to the JSON property dateRange
2524 2525 2526 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2524 def date_range @date_range end |
#display_name ⇒ String
Required. The display name of the budget. Must be UTF-8 encoded with a maximum
size of 240 bytes.
Corresponds to the JSON property displayName
2530 2531 2532 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2530 def display_name @display_name end |
#external_budget_id ⇒ String
Immutable. The ID identifying this budget to the external source. If this
field is set and the invoice detail level of the corresponding billing profile
is set to "Budget level PO", all impressions served against this budget will
include this ID on the invoice. Must be unique under the campaign.
Corresponds to the JSON property externalBudgetId
2538 2539 2540 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2538 def external_budget_id @external_budget_id end |
#external_budget_source ⇒ String
Required. The external source of the budget.
Corresponds to the JSON property externalBudgetSource
2543 2544 2545 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2543 def external_budget_source @external_budget_source end |
#invoice_grouping_id ⇒ String
Immutable. The ID used to group budgets to be included the same invoice. If
this field is set and the invoice level of the corresponding billing profile
is set to "Budget invoice grouping ID", all external_budget_id sharing the
same invoice_grouping_id will be grouped in the same invoice.
Corresponds to the JSON property invoiceGroupingId
2551 2552 2553 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2551 def invoice_grouping_id @invoice_grouping_id end |
#prisma_config ⇒ Google::Apis::DisplayvideoV2::PrismaConfig
Settings specific to the Mediaocean Prisma tool.
Corresponds to the JSON property prismaConfig
2556 2557 2558 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2556 def prisma_config @prisma_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2563 def update!(**args) @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros) @budget_id = args[:budget_id] if args.key?(:budget_id) @budget_unit = args[:budget_unit] if args.key?(:budget_unit) @date_range = args[:date_range] if args.key?(:date_range) @display_name = args[:display_name] if args.key?(:display_name) @external_budget_id = args[:external_budget_id] if args.key?(:external_budget_id) @external_budget_source = args[:external_budget_source] if args.key?(:external_budget_source) @invoice_grouping_id = args[:invoice_grouping_id] if args.key?(:invoice_grouping_id) @prisma_config = args[:prisma_config] if args.key?(:prisma_config) end |