Class: Google::Apis::DisplayvideoV2::CampaignFlight

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings that track the planned spend and duration of a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CampaignFlight

Returns a new instance of CampaignFlight.



2585
2586
2587
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#planned_datesGoogle::Apis::DisplayvideoV2::DateRange

A date range. Corresponds to the JSON property plannedDates



2575
2576
2577
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2575

def planned_dates
  @planned_dates
end

#planned_spend_amount_microsFixnum

The amount the campaign is expected to spend for its given planned_dates. This will not limit serving, but will be used for tracking spend in the DV360 UI. The amount is in micros. Must be greater than or equal to 0. For example, 500000000 represents 500 standard units of the currency. Corresponds to the JSON property plannedSpendAmountMicros

Returns:

  • (Fixnum)


2583
2584
2585
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2583

def planned_spend_amount_micros
  @planned_spend_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2590
2591
2592
2593
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2590

def update!(**args)
  @planned_dates = args[:planned_dates] if args.key?(:planned_dates)
  @planned_spend_amount_micros = args[:planned_spend_amount_micros] if args.key?(:planned_spend_amount_micros)
end