Class: Google::Apis::DisplayvideoV2::CarrierAndIspAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for assigned carrier and ISP targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_CARRIER_AND_ISP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarrierAndIspAssignedTargetingOptionDetails

Returns a new instance of CarrierAndIspAssignedTargetingOptionDetails.



2646
2647
2648
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the carrier or ISP. Corresponds to the JSON property displayName

Returns:

  • (String)


2630
2631
2632
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2630

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned carrier and ISP targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


2637
2638
2639
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2637

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_CARRIER_AND_ISP. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


2644
2645
2646
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2644

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2651
2652
2653
2654
2655
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2651

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end