Class: Google::Apis::DisplayvideoV2::CmHybridConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::CmHybridConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Settings for advertisers that use both Campaign Manager 360 (CM360) and third- party ad servers.
Instance Attribute Summary collapse
-
#cm_account_id ⇒ Fixnum
Required.
-
#cm_advertiser_ids ⇒ Array<Fixnum>
Output only.
-
#cm_floodlight_config_id ⇒ Fixnum
Required.
-
#cm_floodlight_linking_authorized ⇒ Boolean
(also: #cm_floodlight_linking_authorized?)
Required.
-
#cm_syncable_site_ids ⇒ Array<Fixnum>
A list of CM360 sites whose placements will be synced to DV360 as creatives.
-
#dv360_to_cm_cost_reporting_enabled ⇒ Boolean
(also: #dv360_to_cm_cost_reporting_enabled?)
Whether or not to report DV360 cost to CM360.
-
#dv360_to_cm_data_sharing_enabled ⇒ Boolean
(also: #dv360_to_cm_data_sharing_enabled?)
Whether or not to include DV360 data in CM360 data transfer reports.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CmHybridConfig
constructor
A new instance of CmHybridConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CmHybridConfig
Returns a new instance of CmHybridConfig.
2881 2882 2883 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cm_account_id ⇒ Fixnum
Required. Immutable. Account ID of the CM360 Floodlight configuration linked
with the DV360 advertiser.
Corresponds to the JSON property cmAccountId
2839 2840 2841 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2839 def cm_account_id @cm_account_id end |
#cm_advertiser_ids ⇒ Array<Fixnum>
Output only. The set of CM360 Advertiser IDs sharing the CM360 Floodlight
configuration.
Corresponds to the JSON property cmAdvertiserIds
2845 2846 2847 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2845 def cm_advertiser_ids @cm_advertiser_ids end |
#cm_floodlight_config_id ⇒ Fixnum
Required. Immutable. ID of the CM360 Floodlight configuration linked with the
DV360 advertiser.
Corresponds to the JSON property cmFloodlightConfigId
2851 2852 2853 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2851 def cm_floodlight_config_id @cm_floodlight_config_id end |
#cm_floodlight_linking_authorized ⇒ Boolean Also known as:
Required. Immutable. By setting this field to true, you, on behalf of your
company, authorize the sharing of information from the given Floodlight
configuration to this Display & Video 360 advertiser.
Corresponds to the JSON property cmFloodlightLinkingAuthorized
2858 2859 2860 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2858 def @cm_floodlight_linking_authorized end |
#cm_syncable_site_ids ⇒ Array<Fixnum>
A list of CM360 sites whose placements will be synced to DV360 as creatives.
If absent or empty in CreateAdvertiser method, the system will automatically
create a CM360 site. Removing sites from this list may cause DV360 creatives
synced from CM360 to be deleted. At least one site must be specified.
Corresponds to the JSON property cmSyncableSiteIds
2867 2868 2869 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2867 def cm_syncable_site_ids @cm_syncable_site_ids end |
#dv360_to_cm_cost_reporting_enabled ⇒ Boolean Also known as: dv360_to_cm_cost_reporting_enabled?
Whether or not to report DV360 cost to CM360.
Corresponds to the JSON property dv360ToCmCostReportingEnabled
2872 2873 2874 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2872 def dv360_to_cm_cost_reporting_enabled @dv360_to_cm_cost_reporting_enabled end |
#dv360_to_cm_data_sharing_enabled ⇒ Boolean Also known as: dv360_to_cm_data_sharing_enabled?
Whether or not to include DV360 data in CM360 data transfer reports.
Corresponds to the JSON property dv360ToCmDataSharingEnabled
2878 2879 2880 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2878 def dv360_to_cm_data_sharing_enabled @dv360_to_cm_data_sharing_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2886 def update!(**args) @cm_account_id = args[:cm_account_id] if args.key?(:cm_account_id) @cm_advertiser_ids = args[:cm_advertiser_ids] if args.key?(:cm_advertiser_ids) @cm_floodlight_config_id = args[:cm_floodlight_config_id] if args.key?(:cm_floodlight_config_id) @cm_floodlight_linking_authorized = args[:cm_floodlight_linking_authorized] if args.key?(:cm_floodlight_linking_authorized) @cm_syncable_site_ids = args[:cm_syncable_site_ids] if args.key?(:cm_syncable_site_ids) @dv360_to_cm_cost_reporting_enabled = args[:dv360_to_cm_cost_reporting_enabled] if args.key?(:dv360_to_cm_cost_reporting_enabled) @dv360_to_cm_data_sharing_enabled = args[:dv360_to_cm_data_sharing_enabled] if args.key?(:dv360_to_cm_data_sharing_enabled) end |