Class: Google::Apis::DisplayvideoV2::CombinedAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::CombinedAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ CombinedAudienceGroup
constructor
A new instance of CombinedAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CombinedAudienceGroup
Returns a new instance of CombinedAudienceGroup.
2996 2997 2998 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV2::CombinedAudienceTargetingSetting>
Required. All combined audience targeting settings in combined audience group.
Repeated settings with the same id will be ignored. The number of combined
audience settings should be no more than five, error will be thrown otherwise.
Corresponds to the JSON property settings
2994 2995 2996 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2994 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3001 3002 3003 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3001 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |