Class: Google::Apis::DisplayvideoV2::CombinedAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::CombinedAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ CombinedAudienceGroup
constructor
A new instance of CombinedAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CombinedAudienceGroup
Returns a new instance of CombinedAudienceGroup.
2971 2972 2973 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV2::CombinedAudienceTargetingSetting>
Required. All combined audience targeting settings in combined audience group.
Repeated settings with the same id will be ignored. The number of combined
audience settings should be no more than five, error will be thrown otherwise.
Corresponds to the JSON property settings
2969 2970 2971 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2969 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2976 2977 2978 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 2976 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |