Class: Google::Apis::DisplayvideoV2::ConversionCountingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversionCountingConfig

Returns a new instance of ConversionCountingConfig.



3358
3359
3360
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_configsArray<Google::Apis::DisplayvideoV2::TrackingFloodlightActivityConfig>

The Floodlight activity configs used to track conversions. The number of conversions counted is the sum of all of the conversions counted by all of the Floodlight activity IDs specified in this field. This field can't be updated if a custom bidding algorithm is assigned to the line item. If you set this field and assign a custom bidding algorithm in the same request, the floodlight activities must match the ones used by the custom bidding algorithm. Corresponds to the JSON property floodlightActivityConfigs



3339
3340
3341
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3339

def floodlight_activity_configs
  @floodlight_activity_configs
end

#post_view_count_percentage_millisFixnum

The percentage of post-view conversions to count, in millis (1/1000 of a percent). Must be between 0 and 100000 inclusive. For example, to track 50% of the post-click conversions, set a value of 50000. Corresponds to the JSON property postViewCountPercentageMillis

Returns:

  • (Fixnum)


3346
3347
3348
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3346

def post_view_count_percentage_millis
  @post_view_count_percentage_millis
end

#primary_attribution_model_idFixnum

Optional. The attribution model to use for conversion measurement. This attribution model will determine how conversions are counted. The Primary model can be set by you for a floodlight config or group. More details here. Only applicable to Demand Gen line items. Retrieval and management of Demand Gen resources is currently in beta. This field is only available to allowlisted users. Corresponds to the JSON property primaryAttributionModelId

Returns:

  • (Fixnum)


3356
3357
3358
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3356

def primary_attribution_model_id
  @primary_attribution_model_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3363
3364
3365
3366
3367
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3363

def update!(**args)
  @floodlight_activity_configs = args[:floodlight_activity_configs] if args.key?(:floodlight_activity_configs)
  @post_view_count_percentage_millis = args[:post_view_count_percentage_millis] if args.key?(:post_view_count_percentage_millis)
  @primary_attribution_model_id = args[:primary_attribution_model_id] if args.key?(:primary_attribution_model_id)
end