Class: Google::Apis::DisplayvideoV2::CreateSdfDownloadTaskRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Request message for [SdfDownloadTaskService.CreateSdfDownloadTask].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateSdfDownloadTaskRequest

Returns a new instance of CreateSdfDownloadTaskRequest.



3498
3499
3500
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser to download SDF for. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


3467
3468
3469
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3467

def advertiser_id
  @advertiser_id
end

#id_filterGoogle::Apis::DisplayvideoV2::IdFilter

A filtering option that filters entities by their entity IDs. Corresponds to the JSON property idFilter



3472
3473
3474
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3472

def id_filter
  @id_filter
end

#inventory_source_filterGoogle::Apis::DisplayvideoV2::InventorySourceFilter

A filtering option for filtering on Inventory Source entities. Corresponds to the JSON property inventorySourceFilter



3477
3478
3479
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3477

def inventory_source_filter
  @inventory_source_filter
end

#parent_entity_filterGoogle::Apis::DisplayvideoV2::ParentEntityFilter

A filtering option that filters on selected file types belonging to a chosen set of filter entities. Corresponds to the JSON property parentEntityFilter



3483
3484
3485
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3483

def parent_entity_filter
  @parent_entity_filter
end

#partner_idFixnum

The ID of the partner to download SDF for. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


3488
3489
3490
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3488

def partner_id
  @partner_id
end

#versionString

Required. The SDF version of the downloaded file. If set to SDF_VERSION_UNSPECIFIED, this will default to the version specified by the advertiser or partner identified by root_id. An advertiser inherits its SDF version from its partner unless configured otherwise. Corresponds to the JSON property version

Returns:

  • (String)


3496
3497
3498
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3496

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3503
3504
3505
3506
3507
3508
3509
3510
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 3503

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @id_filter = args[:id_filter] if args.key?(:id_filter)
  @inventory_source_filter = args[:inventory_source_filter] if args.key?(:inventory_source_filter)
  @parent_entity_filter = args[:parent_entity_filter] if args.key?(:parent_entity_filter)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @version = args[:version] if args.key?(:version)
end