Class: Google::Apis::DisplayvideoV2::DemandGenBiddingStrategy
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::DemandGenBiddingStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Settings that control the bid strategy for Demand Gen resources.
Instance Attribute Summary collapse
-
#effective_bidding_value ⇒ Fixnum
Output only.
-
#effective_bidding_value_source ⇒ String
Output only.
-
#type ⇒ String
Optional.
-
#value ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenBiddingStrategy
constructor
A new instance of DemandGenBiddingStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenBiddingStrategy
Returns a new instance of DemandGenBiddingStrategy.
4425 4426 4427 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_bidding_value ⇒ Fixnum
Output only. The value effectively used by the bidding strategy. This field
will be the same as value if set. If value is not set and the strategy is
assigned to an ad group, this field will be inherited from the line item's
bidding strategy. If type is not DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA
or DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS, this field will be 0.
Corresponds to the JSON property effectiveBiddingValue
4400 4401 4402 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4400 def effective_bidding_value @effective_bidding_value end |
#effective_bidding_value_source ⇒ String
Output only. Source of the effective bidding value.
Corresponds to the JSON property effectiveBiddingValueSource
4405 4406 4407 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4405 def effective_bidding_value_source @effective_bidding_value_source end |
#type ⇒ String
Optional. The type of the bidding strategy. This can only be set when assigned
to a line item. Ad groups will inherit this value from their line item.
Corresponds to the JSON property type
4411 4412 4413 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4411 def type @type end |
#value ⇒ Fixnum
Optional. The value used by the bidding strategy. This can be set when
assigned to line items or ad groups. This field is only applicable for the
following strategy types: * DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA *
DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPC *
DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS Value of this field is in micros
of the advertiser's currency or ROAS value. For example, 1000000 represents 1.
0 standard units of the currency or 100% ROAS value. If not using an
applicable strategy, the value of this field will be 0.
Corresponds to the JSON property value
4423 4424 4425 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4423 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4430 4431 4432 4433 4434 4435 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4430 def update!(**args) @effective_bidding_value = args[:effective_bidding_value] if args.key?(:effective_bidding_value) @effective_bidding_value_source = args[:effective_bidding_value_source] if args.key?(:effective_bidding_value_source) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |