Class: Google::Apis::DisplayvideoV2::DemandGenSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings for Demand Gen line items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenSettings

Returns a new instance of DemandGenSettings.



4471
4472
4473
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geo_language_targeting_enabledBoolean Also known as: geo_language_targeting_enabled?

Optional. Immutable. Whether location and language targeting can be set at the line item level. Otherwise, relevant targeting types must be assigned directly to ad groups. Corresponds to the JSON property geoLanguageTargetingEnabled

Returns:

  • (Boolean)


4456
4457
4458
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4456

def geo_language_targeting_enabled
  @geo_language_targeting_enabled
end

#linked_merchant_idFixnum

Optional. The ID of the Merchant Center account used to provide a product feed. This Merchant Center account must already be linked to the advertiser. Corresponds to the JSON property linkedMerchantId

Returns:

  • (Fixnum)


4463
4464
4465
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4463

def linked_merchant_id
  @linked_merchant_id
end

#third_party_measurement_configsGoogle::Apis::DisplayvideoV2::ThirdPartyMeasurementConfigs

Settings that control what third-party vendors are measuring specific line item metrics. Corresponds to the JSON property thirdPartyMeasurementConfigs



4469
4470
4471
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4469

def third_party_measurement_configs
  @third_party_measurement_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4476
4477
4478
4479
4480
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4476

def update!(**args)
  @geo_language_targeting_enabled = args[:geo_language_targeting_enabled] if args.key?(:geo_language_targeting_enabled)
  @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id)
  @third_party_measurement_configs = args[:third_party_measurement_configs] if args.key?(:third_party_measurement_configs)
end