Class: Google::Apis::DisplayvideoV2::DemandGenSettings
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::DemandGenSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Settings for Demand Gen line items.
Instance Attribute Summary collapse
-
#geo_language_targeting_enabled ⇒ Boolean
(also: #geo_language_targeting_enabled?)
Optional.
-
#linked_merchant_id ⇒ Fixnum
Optional.
-
#third_party_measurement_configs ⇒ Google::Apis::DisplayvideoV2::ThirdPartyMeasurementConfigs
Settings that control what third-party vendors are measuring specific line item metrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenSettings
constructor
A new instance of DemandGenSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenSettings
Returns a new instance of DemandGenSettings.
4462 4463 4464 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#geo_language_targeting_enabled ⇒ Boolean Also known as: geo_language_targeting_enabled?
Optional. Immutable. Whether location and language targeting can be set at the
line item level. Otherwise, relevant targeting types must be assigned directly
to ad groups.
Corresponds to the JSON property geoLanguageTargetingEnabled
4447 4448 4449 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4447 def geo_language_targeting_enabled @geo_language_targeting_enabled end |
#linked_merchant_id ⇒ Fixnum
Optional. The ID of the Merchant Center account used to provide a product feed.
This Merchant Center account must already be linked to the advertiser.
Corresponds to the JSON property linkedMerchantId
4454 4455 4456 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4454 def linked_merchant_id @linked_merchant_id end |
#third_party_measurement_configs ⇒ Google::Apis::DisplayvideoV2::ThirdPartyMeasurementConfigs
Settings that control what third-party vendors are measuring specific line
item metrics.
Corresponds to the JSON property thirdPartyMeasurementConfigs
4460 4461 4462 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4460 def third_party_measurement_configs @third_party_measurement_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4467 4468 4469 4470 4471 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4467 def update!(**args) @geo_language_targeting_enabled = args[:geo_language_targeting_enabled] if args.key?(:geo_language_targeting_enabled) @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id) @third_party_measurement_configs = args[:third_party_measurement_configs] if args.key?(:third_party_measurement_configs) end |