Class: Google::Apis::DisplayvideoV2::DuplicateLineItemRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::DuplicateLineItemRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Request message for LineItemService.DuplicateLineItem.
Instance Attribute Summary collapse
-
#contains_eu_political_ads ⇒ String
Whether this line item will serve European Union political ads.
-
#target_display_name ⇒ String
The display name of the new line item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DuplicateLineItemRequest
constructor
A new instance of DuplicateLineItemRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DuplicateLineItemRequest
Returns a new instance of DuplicateLineItemRequest.
4890 4891 4892 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains_eu_political_ads ⇒ String
Whether this line item will serve European Union political ads. If
contains_eu_political_ads has been set to
DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this
field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not
otherwise specified. This field can then be updated using the UI, API, or
Structured Data Files. This field must be assigned when creating a new line
item. Otherwise, the advertisers.lineItems.create request will fail.
Corresponds to the JSON property containsEuPoliticalAds
4882 4883 4884 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4882 def contains_eu_political_ads @contains_eu_political_ads end |
#target_display_name ⇒ String
The display name of the new line item. Must be UTF-8 encoded with a maximum
size of 240 bytes.
Corresponds to the JSON property targetDisplayName
4888 4889 4890 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4888 def target_display_name @target_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4895 4896 4897 4898 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 4895 def update!(**args) @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads) @target_display_name = args[:target_display_name] if args.key?(:target_display_name) end |