Class: Google::Apis::DisplayvideoV2::ExitEvent
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::ExitEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Exit event of the creative.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#reporting_name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExitEvent
constructor
A new instance of ExitEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExitEvent
Returns a new instance of ExitEvent.
5230 5231 5232 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. The name of the click tag of the exit event. The name must be unique
within one creative. Leave it empty or unset for creatives containing image
assets only.
Corresponds to the JSON property name
5211 5212 5213 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5211 def name @name end |
#reporting_name ⇒ String
Optional. The name used to identify this event in reports. Leave it empty or
unset for creatives containing image assets only.
Corresponds to the JSON property reportingName
5217 5218 5219 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5217 def reporting_name @reporting_name end |
#type ⇒ String
Required. The type of the exit event.
Corresponds to the JSON property type
5222 5223 5224 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5222 def type @type end |
#url ⇒ String
Required. The click through URL of the exit event. This is required when type
is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP
Corresponds to the JSON property url
5228 5229 5230 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5228 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5235 5236 5237 5238 5239 5240 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5235 def update!(**args) @name = args[:name] if args.key?(:name) @reporting_name = args[:reporting_name] if args.key?(:reporting_name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |