Class: Google::Apis::DisplayvideoV2::ExitEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Exit event of the creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExitEvent

Returns a new instance of ExitEvent.



5199
5200
5201
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Optional. The name of the click tag of the exit event. The name must be unique within one creative. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property name

Returns:

  • (String)


5180
5181
5182
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5180

def name
  @name
end

#reporting_nameString

Optional. The name used to identify this event in reports. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property reportingName

Returns:

  • (String)


5186
5187
5188
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5186

def reporting_name
  @reporting_name
end

#typeString

Required. The type of the exit event. Corresponds to the JSON property type

Returns:

  • (String)


5191
5192
5193
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5191

def type
  @type
end

#urlString

Required. The click through URL of the exit event. This is required when type is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP Corresponds to the JSON property url

Returns:

  • (String)


5197
5198
5199
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5197

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5204
5205
5206
5207
5208
5209
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5204

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @reporting_name = args[:reporting_name] if args.key?(:reporting_name)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end