Class: Google::Apis::DisplayvideoV2::FloodlightActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single Floodlight activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivity

Returns a new instance of FloodlightActivity.



5285
5286
5287
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idsArray<Fixnum>

Output only. IDs of the advertisers that have access to the parent Floodlight group. Only advertisers under the provided partner ID will be listed in this field. Corresponds to the JSON property advertiserIds

Returns:

  • (Array<Fixnum>)


5244
5245
5246
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5244

def advertiser_ids
  @advertiser_ids
end

#display_nameString

Required. The display name of the Floodlight activity. Corresponds to the JSON property displayName

Returns:

  • (String)


5249
5250
5251
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5249

def display_name
  @display_name
end

#floodlight_activity_idFixnum

Output only. The unique ID of the Floodlight activity. Assigned by the system. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


5254
5255
5256
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5254

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_group_idFixnum

Required. Immutable. The ID of the parent Floodlight group. Corresponds to the JSON property floodlightGroupId

Returns:

  • (Fixnum)


5259
5260
5261
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5259

def floodlight_group_id
  @floodlight_group_id
end

#nameString

Output only. The resource name of the Floodlight activity. Corresponds to the JSON property name

Returns:

  • (String)


5264
5265
5266
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5264

def name
  @name
end

#remarketing_configsArray<Google::Apis::DisplayvideoV2::RemarketingConfig>

Output only. A list of configuration objects designating whether remarketing for this Floodlight Activity is enabled and available for a specifc advertiser. If enabled, this Floodlight Activity generates a remarketing user list that is able to be used in targeting under the advertiser. Corresponds to the JSON property remarketingConfigs



5272
5273
5274
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5272

def remarketing_configs
  @remarketing_configs
end

#serving_statusString

Optional. Whether the Floodlight activity is served. Corresponds to the JSON property servingStatus

Returns:

  • (String)


5277
5278
5279
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5277

def serving_status
  @serving_status
end

#ssl_requiredBoolean Also known as: ssl_required?

Output only. Whether tags are required to be compliant. Corresponds to the JSON property sslRequired

Returns:

  • (Boolean)


5282
5283
5284
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5282

def ssl_required
  @ssl_required
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5290

def update!(**args)
  @advertiser_ids = args[:advertiser_ids] if args.key?(:advertiser_ids)
  @display_name = args[:display_name] if args.key?(:display_name)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id)
  @name = args[:name] if args.key?(:name)
  @remarketing_configs = args[:remarketing_configs] if args.key?(:remarketing_configs)
  @serving_status = args[:serving_status] if args.key?(:serving_status)
  @ssl_required = args[:ssl_required] if args.key?(:ssl_required)
end