Class: Google::Apis::DisplayvideoV2::FrequencyCap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings that control the number of times a user may be shown with the same ad during a given time period.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FrequencyCap

Returns a new instance of FrequencyCap.



5421
5422
5423
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_impressionsFixnum

The maximum number of times a user may be shown the same ad during this period. Must be greater than 0. Required when unlimited is false and max_views is not set. Corresponds to the JSON property maxImpressions

Returns:

  • (Fixnum)


5389
5390
5391
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5389

def max_impressions
  @max_impressions
end

#max_viewsFixnum

Optional. The maximum number of times a user may click-through or fully view an ad during this period until it is no longer served to them. Must be greater than 0. Only applicable to YouTube and Partners resources. Required when unlimited is false and max_impressions is not set. Corresponds to the JSON property maxViews

Returns:

  • (Fixnum)


5397
5398
5399
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5397

def max_views
  @max_views
end

#time_unitString

The time unit in which the frequency cap will be applied. Required when unlimited is false. Corresponds to the JSON property timeUnit

Returns:

  • (String)


5403
5404
5405
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5403

def time_unit
  @time_unit
end

#time_unit_countFixnum

The number of time_unit the frequency cap will last. Required when unlimited is false. The following restrictions apply based on the value of time_unit: * TIME_UNIT_MONTHS - must be 1 * TIME_UNIT_WEEKS - must be between 1 and 4 * TIME_UNIT_DAYS - must be between 1 and 6 * TIME_UNIT_HOURS - must be between 1 and 23 * TIME_UNIT_MINUTES - must be between 1 and 59 Corresponds to the JSON property timeUnitCount

Returns:

  • (Fixnum)


5412
5413
5414
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5412

def time_unit_count
  @time_unit_count
end

#unlimitedBoolean Also known as: unlimited?

Whether unlimited frequency capping is applied. When this field is set to true, the remaining frequency cap fields are not applicable. Corresponds to the JSON property unlimited

Returns:

  • (Boolean)


5418
5419
5420
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5418

def unlimited
  @unlimited
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5426
5427
5428
5429
5430
5431
5432
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5426

def update!(**args)
  @max_impressions = args[:max_impressions] if args.key?(:max_impressions)
  @max_views = args[:max_views] if args.key?(:max_views)
  @time_unit = args[:time_unit] if args.key?(:time_unit)
  @time_unit_count = args[:time_unit_count] if args.key?(:time_unit_count)
  @unlimited = args[:unlimited] if args.key?(:unlimited)
end