Class: Google::Apis::DisplayvideoV2::InsertionOrder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single insertion order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrder

Returns a new instance of InsertionOrder.



6070
6071
6072
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the insertion order belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


5974
5975
5976
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5974

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV2::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



5979
5980
5981
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5979

def bid_strategy
  @bid_strategy
end

#billable_outcomeString

Immutable. The billable outcome of the insertion order. Outcome based buying is deprecated. BILLABLE_OUTCOME_PAY_PER_IMPRESSION is the only valid value. Corresponds to the JSON property billableOutcome

Returns:

  • (String)


5985
5986
5987
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5985

def billable_outcome
  @billable_outcome
end

#budgetGoogle::Apis::DisplayvideoV2::InsertionOrderBudget

Settings that control how insertion order budget is allocated. Corresponds to the JSON property budget



5990
5991
5992
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5990

def budget
  @budget
end

#campaign_idFixnum

Required. Immutable. The unique ID of the campaign that the insertion order belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


5996
5997
5998
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 5996

def campaign_id
  @campaign_id
end

#display_nameString

Required. The display name of the insertion order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


6002
6003
6004
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6002

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the insertion order can spend its budget and bid on inventory. * For CreateInsertionOrder method, only ENTITY_STATUS_DRAFT is allowed. To activate an insertion order, use UpdateInsertionOrder method and update the status to ENTITY_STATUS_ACTIVE after creation. * An insertion order cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * An insertion order cannot be set to ENTITY_STATUS_ACTIVE if its parent campaign is not active. Corresponds to the JSON property entityStatus

Returns:

  • (String)


6013
6014
6015
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6013

def entity_status
  @entity_status
end

#frequency_capGoogle::Apis::DisplayvideoV2::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



6019
6020
6021
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6019

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Output only. The unique ID of the insertion order. Assigned by the system. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


6024
6025
6026
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6024

def insertion_order_id
  @insertion_order_id
end

#insertion_order_typeString

Optional. The type of insertion order. If this field is unspecified in creation, the value defaults to RTB. Corresponds to the JSON property insertionOrderType

Returns:

  • (String)


6030
6031
6032
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6030

def insertion_order_type
  @insertion_order_type
end

#integration_detailsGoogle::Apis::DisplayvideoV2::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



6035
6036
6037
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6035

def integration_details
  @integration_details
end

#nameString

Output only. The resource name of the insertion order. Corresponds to the JSON property name

Returns:

  • (String)


6040
6041
6042
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6040

def name
  @name
end

#pacingGoogle::Apis::DisplayvideoV2::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



6045
6046
6047
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6045

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV2::PartnerCost>

Optional. The partner costs associated with the insertion order. If absent or empty in CreateInsertionOrder method, the newly created insertion order will inherit partner costs from the partner settings. Corresponds to the JSON property partnerCosts



6052
6053
6054
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6052

def partner_costs
  @partner_costs
end

#performance_goalGoogle::Apis::DisplayvideoV2::PerformanceGoal

Settings that control the performance goal of a campaign. Corresponds to the JSON property performanceGoal



6057
6058
6059
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6057

def performance_goal
  @performance_goal
end

#reservation_typeString

Output only. The reservation type of the insertion order. Corresponds to the JSON property reservationType

Returns:

  • (String)


6062
6063
6064
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6062

def reservation_type
  @reservation_type
end

#update_timeString

Output only. The timestamp when the insertion order was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


6068
6069
6070
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6068

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
6093
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6075

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @billable_outcome = args[:billable_outcome] if args.key?(:billable_outcome)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @insertion_order_type = args[:insertion_order_type] if args.key?(:insertion_order_type)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @name = args[:name] if args.key?(:name)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @performance_goal = args[:performance_goal] if args.key?(:performance_goal)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end