Class: Google::Apis::DisplayvideoV2::Invoice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single invoice.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Invoice

Returns a new instance of Invoice.



6548
6549
6550
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_invoice_grouping_idString

The budget grouping ID for this invoice. This field will only be set if the invoice level of the corresponding billing profile was set to "Budget invoice grouping ID". Corresponds to the JSON property budgetInvoiceGroupingId

Returns:

  • (String)


6416
6417
6418
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6416

def budget_invoice_grouping_id
  @budget_invoice_grouping_id
end

#budget_summariesArray<Google::Apis::DisplayvideoV2::BudgetSummary>

The list of summarized information for each budget associated with this invoice. This field will only be set if the invoice detail level of the corresponding billing profile was set to "Budget level PO". Corresponds to the JSON property budgetSummaries



6423
6424
6425
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6423

def budget_summaries
  @budget_summaries
end

#corrected_invoice_idString

The ID of the original invoice being adjusted by this invoice, if applicable. May appear on the invoice PDF as Reference invoice number. If replaced_invoice_ids is set, this field will be empty. Corresponds to the JSON property correctedInvoiceId

Returns:

  • (String)


6430
6431
6432
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6430

def corrected_invoice_id
  @corrected_invoice_id
end

#currency_codeString

The currency used in the invoice in ISO 4217 format. Corresponds to the JSON property currencyCode

Returns:

  • (String)


6435
6436
6437
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6435

def currency_code
  @currency_code
end

#display_nameString

The display name of the invoice. Corresponds to the JSON property displayName

Returns:

  • (String)


6440
6441
6442
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6440

def display_name
  @display_name
end

#due_dateGoogle::Apis::DisplayvideoV2::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property dueDate



6452
6453
6454
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6452

def due_date
  @due_date
end

#invoice_idString

The unique ID of the invoice. Corresponds to the JSON property invoiceId

Returns:

  • (String)


6457
6458
6459
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6457

def invoice_id
  @invoice_id
end

#invoice_typeString

The type of invoice document. Corresponds to the JSON property invoiceType

Returns:

  • (String)


6462
6463
6464
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6462

def invoice_type
  @invoice_type
end

#issue_dateGoogle::Apis::DisplayvideoV2::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property issueDate



6474
6475
6476
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6474

def issue_date
  @issue_date
end

#nameString

The resource name of the invoice. Corresponds to the JSON property name

Returns:

  • (String)


6479
6480
6481
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6479

def name
  @name
end

#non_budget_microsFixnum

The total amount of costs or adjustments not tied to a particular budget, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property nonBudgetMicros

Returns:

  • (Fixnum)


6486
6487
6488
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6486

def non_budget_micros
  @non_budget_micros
end

#payments_account_idString

The ID of the payments account the invoice belongs to. Appears on the invoice PDF as Billing Account Number. Corresponds to the JSON property paymentsAccountId

Returns:

  • (String)


6492
6493
6494
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6492

def 
  @payments_account_id
end

#payments_profile_idString

The ID of the payments profile the invoice belongs to. Appears on the invoice PDF as Billing ID. Corresponds to the JSON property paymentsProfileId

Returns:

  • (String)


6498
6499
6500
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6498

def payments_profile_id
  @payments_profile_id
end

#pdf_urlString

The URL to download a PDF copy of the invoice. This URL is user specific and requires a valid OAuth 2.0 access token to access. The access token must be provided in an Authorization: Bearer HTTP header and be authorized for one of the following scopes: * https://www.googleapis.com/auth/display-video- mediaplanning * https://www.googleapis.com/auth/display-video The URL will be valid for 7 days after retrieval of this invoice object or until this invoice is retrieved again. Corresponds to the JSON property pdfUrl

Returns:

  • (String)


6509
6510
6511
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6509

def pdf_url
  @pdf_url
end

#purchase_order_numberString

Purchase order number associated with the invoice. Corresponds to the JSON property purchaseOrderNumber

Returns:

  • (String)


6514
6515
6516
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6514

def purchase_order_number
  @purchase_order_number
end

#replaced_invoice_idsArray<String>

The ID(s) of any originally issued invoice that is being cancelled by this invoice, if applicable. Multiple invoices may be listed if those invoices are being consolidated into a single invoice. May appear on invoice PDF as Replaced invoice numbers. If corrected_invoice_id is set, this field will be empty. Corresponds to the JSON property replacedInvoiceIds

Returns:

  • (Array<String>)


6523
6524
6525
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6523

def replaced_invoice_ids
  @replaced_invoice_ids
end

#service_date_rangeGoogle::Apis::DisplayvideoV2::DateRange

A date range. Corresponds to the JSON property serviceDateRange



6528
6529
6530
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6528

def service_date_range
  @service_date_range
end

#subtotal_amount_microsFixnum

The pre-tax subtotal amount, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property subtotalAmountMicros

Returns:

  • (Fixnum)


6534
6535
6536
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6534

def subtotal_amount_micros
  @subtotal_amount_micros
end

#total_amount_microsFixnum

The invoice total amount, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


6540
6541
6542
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6540

def total_amount_micros
  @total_amount_micros
end

#total_tax_amount_microsFixnum

The sum of all taxes in invoice, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property totalTaxAmountMicros

Returns:

  • (Fixnum)


6546
6547
6548
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6546

def total_tax_amount_micros
  @total_tax_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
6565
6566
6567
6568
6569
6570
6571
6572
6573
6574
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6553

def update!(**args)
  @budget_invoice_grouping_id = args[:budget_invoice_grouping_id] if args.key?(:budget_invoice_grouping_id)
  @budget_summaries = args[:budget_summaries] if args.key?(:budget_summaries)
  @corrected_invoice_id = args[:corrected_invoice_id] if args.key?(:corrected_invoice_id)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @display_name = args[:display_name] if args.key?(:display_name)
  @due_date = args[:due_date] if args.key?(:due_date)
  @invoice_id = args[:invoice_id] if args.key?(:invoice_id)
  @invoice_type = args[:invoice_type] if args.key?(:invoice_type)
  @issue_date = args[:issue_date] if args.key?(:issue_date)
  @name = args[:name] if args.key?(:name)
  @non_budget_micros = args[:non_budget_micros] if args.key?(:non_budget_micros)
  @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id)
  @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id)
  @pdf_url = args[:pdf_url] if args.key?(:pdf_url)
  @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number)
  @replaced_invoice_ids = args[:replaced_invoice_ids] if args.key?(:replaced_invoice_ids)
  @service_date_range = args[:service_date_range] if args.key?(:service_date_range)
  @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
  @total_tax_amount_micros = args[:total_tax_amount_micros] if args.key?(:total_tax_amount_micros)
end