Class: Google::Apis::DisplayvideoV2::KeywordAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for assigned keyword targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_KEYWORD.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeywordAssignedTargetingOptionDetails

Returns a new instance of KeywordAssignedTargetingOptionDetails.



6607
6608
6609
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempted_policy_namesArray<String>

Optional. The policy names to exempt the keyword from. When attempting to target a keyword that violates a policy, the error returned will include the name of the relevant policy. Use that name in this field to exempt the targeted keyword from the policy. This field is only applicable for positively- targeted keywords assigned to Demand Gen resources. Retrieval and management of Demand Gen resources is currently in beta. This field is only available to allowlisted users. Corresponds to the JSON property exemptedPolicyNames

Returns:

  • (Array<String>)


6592
6593
6594
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6592

def exempted_policy_names
  @exempted_policy_names
end

#keywordString

Required. The keyword, for example car insurance. Positive keyword cannot be offensive word. Must be UTF-8 encoded with a maximum size of 255 bytes. Maximum number of characters is 80. Maximum number of words is 10. Corresponds to the JSON property keyword

Returns:

  • (String)


6599
6600
6601
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6599

def keyword
  @keyword
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. Corresponds to the JSON property negative

Returns:

  • (Boolean)


6604
6605
6606
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6604

def negative
  @negative
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6612
6613
6614
6615
6616
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6612

def update!(**args)
  @exempted_policy_names = args[:exempted_policy_names] if args.key?(:exempted_policy_names)
  @keyword = args[:keyword] if args.key?(:keyword)
  @negative = args[:negative] if args.key?(:negative)
end