Class: Google::Apis::DisplayvideoV2::LineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItem

Returns a new instance of LineItem.



6851
6852
6853
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the line item belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


6682
6683
6684
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6682

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV2::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



6687
6688
6689
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6687

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV2::LineItemBudget

Settings that control how budget is allocated. Corresponds to the JSON property budget



6692
6693
6694
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6692

def budget
  @budget
end

#campaign_idFixnum

Output only. The unique ID of the campaign that the line item belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


6697
6698
6699
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6697

def campaign_id
  @campaign_id
end

#contains_eu_political_adsString

Whether this line item will serve European Union political ads. If contains_eu_political_ads has been set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. This field can then be updated using the UI, API, or Structured Data Files. This field must be assigned when creating a new line item. Otherwise, the advertisers.lineItems.create request will fail. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


6708
6709
6710
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6708

def contains_eu_political_ads
  @contains_eu_political_ads
end

#conversion_countingGoogle::Apis::DisplayvideoV2::ConversionCountingConfig

Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting. Corresponds to the JSON property conversionCounting



6715
6716
6717
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6715

def conversion_counting
  @conversion_counting
end

#creative_idsArray<Fixnum>

The IDs of the creatives associated with the line item. Corresponds to the JSON property creativeIds

Returns:

  • (Array<Fixnum>)


6720
6721
6722
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6720

def creative_ids
  @creative_ids
end

#demand_gen_settingsGoogle::Apis::DisplayvideoV2::DemandGenSettings

Settings for Demand Gen line items. Corresponds to the JSON property demandGenSettings



6725
6726
6727
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6725

def demand_gen_settings
  @demand_gen_settings
end

#display_nameString

Required. The display name of the line item. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


6731
6732
6733
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6731

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the line item can spend its budget and bid on inventory. * For CreateLineItem method, only ENTITY_STATUS_DRAFT is allowed. To activate a line item, use UpdateLineItem method and update the status to ENTITY_STATUS_ACTIVE after creation. * A line item cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * If the line item's parent insertion order is not active, the line item can't spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


6742
6743
6744
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6742

def entity_status
  @entity_status
end

#exclude_new_exchangesBoolean Also known as: exclude_new_exchanges?

Whether to exclude new exchanges from automatically being targeted by the line item. This field is false by default. Corresponds to the JSON property excludeNewExchanges

Returns:

  • (Boolean)


6748
6749
6750
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6748

def exclude_new_exchanges
  @exclude_new_exchanges
end

#flightGoogle::Apis::DisplayvideoV2::LineItemFlight

Settings that control the active duration of a line item. Corresponds to the JSON property flight



6754
6755
6756
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6754

def flight
  @flight
end

#frequency_capGoogle::Apis::DisplayvideoV2::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



6760
6761
6762
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6760

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Required. Immutable. The unique ID of the insertion order that the line item belongs to. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


6766
6767
6768
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6766

def insertion_order_id
  @insertion_order_id
end

#integration_detailsGoogle::Apis::DisplayvideoV2::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



6771
6772
6773
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6771

def integration_details
  @integration_details
end

#line_item_idFixnum

Output only. The unique ID of the line item. Assigned by the system. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


6776
6777
6778
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6776

def line_item_id
  @line_item_id
end

#line_item_typeString

Required. Immutable. The type of the line item. Corresponds to the JSON property lineItemType

Returns:

  • (String)


6781
6782
6783
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6781

def line_item_type
  @line_item_type
end

#mobile_appGoogle::Apis::DisplayvideoV2::MobileApp

A mobile app promoted by a mobile app install line item. Corresponds to the JSON property mobileApp



6786
6787
6788
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6786

def mobile_app
  @mobile_app
end

#nameString

Output only. The resource name of the line item. Corresponds to the JSON property name

Returns:

  • (String)


6791
6792
6793
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6791

def name
  @name
end

#optimize_fixed_biddingBoolean Also known as: optimize_fixed_bidding?

Optional. Whether to enable DV360's bid optimization for fixed bid line items. By default, DV360 optimizes your fixed bid by automatically lowering bids for impressions that are less likely to perform well. This optimization is enabled by default (value is true). When this field is set to false, this optimization is disabled, and the bid will not be lowered for any reason. This setting only applies to line items with a bidding_strategy of type FIXED_BID. Corresponds to the JSON property optimizeFixedBidding

Returns:

  • (Boolean)


6802
6803
6804
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6802

def optimize_fixed_bidding
  @optimize_fixed_bidding
end

#pacingGoogle::Apis::DisplayvideoV2::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



6808
6809
6810
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6808

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV2::PartnerCost>

The partner costs associated with the line item. If absent or empty in CreateLineItem method, the newly created line item will inherit partner costs from its parent insertion order. Corresponds to the JSON property partnerCosts



6815
6816
6817
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6815

def partner_costs
  @partner_costs
end

#partner_revenue_modelGoogle::Apis::DisplayvideoV2::PartnerRevenueModel

Settings that control how partner revenue is calculated. Corresponds to the JSON property partnerRevenueModel



6820
6821
6822
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6820

def partner_revenue_model
  @partner_revenue_model
end

#reservation_typeString

Output only. The reservation type of the line item. Corresponds to the JSON property reservationType

Returns:

  • (String)


6825
6826
6827
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6825

def reservation_type
  @reservation_type
end

#targeting_expansionGoogle::Apis::DisplayvideoV2::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



6831
6832
6833
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6831

def targeting_expansion
  @targeting_expansion
end

#update_timeString

Output only. The timestamp when the line item was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


6837
6838
6839
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6837

def update_time
  @update_time
end

#warning_messagesArray<String>

Output only. The warning messages generated by the line item. These warnings do not block saving the line item, but some may block the line item from running. Corresponds to the JSON property warningMessages

Returns:

  • (Array<String>)


6844
6845
6846
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6844

def warning_messages
  @warning_messages
end

#youtube_and_partners_settingsGoogle::Apis::DisplayvideoV2::YoutubeAndPartnersSettings

Settings for YouTube and Partners line items. Corresponds to the JSON property youtubeAndPartnersSettings



6849
6850
6851
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6849

def youtube_and_partners_settings
  @youtube_and_partners_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6856

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting)
  @creative_ids = args[:creative_ids] if args.key?(:creative_ids)
  @demand_gen_settings = args[:demand_gen_settings] if args.key?(:demand_gen_settings)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exclude_new_exchanges = args[:exclude_new_exchanges] if args.key?(:exclude_new_exchanges)
  @flight = args[:flight] if args.key?(:flight)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @line_item_type = args[:line_item_type] if args.key?(:line_item_type)
  @mobile_app = args[:mobile_app] if args.key?(:mobile_app)
  @name = args[:name] if args.key?(:name)
  @optimize_fixed_bidding = args[:optimize_fixed_bidding] if args.key?(:optimize_fixed_bidding)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @partner_revenue_model = args[:partner_revenue_model] if args.key?(:partner_revenue_model)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
  @update_time = args[:update_time] if args.key?(:update_time)
  @warning_messages = args[:warning_messages] if args.key?(:warning_messages)
  @youtube_and_partners_settings = args[:youtube_and_partners_settings] if args.key?(:youtube_and_partners_settings)
end