Class: Google::Apis::DisplayvideoV2::LineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItem

Returns a new instance of LineItem.



6842
6843
6844
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the line item belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


6673
6674
6675
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6673

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV2::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



6678
6679
6680
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6678

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV2::LineItemBudget

Settings that control how budget is allocated. Corresponds to the JSON property budget



6683
6684
6685
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6683

def budget
  @budget
end

#campaign_idFixnum

Output only. The unique ID of the campaign that the line item belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


6688
6689
6690
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6688

def campaign_id
  @campaign_id
end

#contains_eu_political_adsString

Whether this line item will serve European Union political ads. If contains_eu_political_ads has been set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. This field can then be updated using the UI, API, or Structured Data Files. This field must be assigned when creating a new line item. Otherwise, the advertisers.lineItems.create request will fail. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


6699
6700
6701
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6699

def contains_eu_political_ads
  @contains_eu_political_ads
end

#conversion_countingGoogle::Apis::DisplayvideoV2::ConversionCountingConfig

Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting. Corresponds to the JSON property conversionCounting



6706
6707
6708
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6706

def conversion_counting
  @conversion_counting
end

#creative_idsArray<Fixnum>

The IDs of the creatives associated with the line item. Corresponds to the JSON property creativeIds

Returns:

  • (Array<Fixnum>)


6711
6712
6713
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6711

def creative_ids
  @creative_ids
end

#demand_gen_settingsGoogle::Apis::DisplayvideoV2::DemandGenSettings

Settings for Demand Gen line items. Corresponds to the JSON property demandGenSettings



6716
6717
6718
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6716

def demand_gen_settings
  @demand_gen_settings
end

#display_nameString

Required. The display name of the line item. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


6722
6723
6724
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6722

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the line item can spend its budget and bid on inventory. * For CreateLineItem method, only ENTITY_STATUS_DRAFT is allowed. To activate a line item, use UpdateLineItem method and update the status to ENTITY_STATUS_ACTIVE after creation. * A line item cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * If the line item's parent insertion order is not active, the line item can't spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


6733
6734
6735
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6733

def entity_status
  @entity_status
end

#exclude_new_exchangesBoolean Also known as: exclude_new_exchanges?

Whether to exclude new exchanges from automatically being targeted by the line item. This field is false by default. Corresponds to the JSON property excludeNewExchanges

Returns:

  • (Boolean)


6739
6740
6741
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6739

def exclude_new_exchanges
  @exclude_new_exchanges
end

#flightGoogle::Apis::DisplayvideoV2::LineItemFlight

Settings that control the active duration of a line item. Corresponds to the JSON property flight



6745
6746
6747
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6745

def flight
  @flight
end

#frequency_capGoogle::Apis::DisplayvideoV2::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



6751
6752
6753
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6751

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Required. Immutable. The unique ID of the insertion order that the line item belongs to. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


6757
6758
6759
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6757

def insertion_order_id
  @insertion_order_id
end

#integration_detailsGoogle::Apis::DisplayvideoV2::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



6762
6763
6764
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6762

def integration_details
  @integration_details
end

#line_item_idFixnum

Output only. The unique ID of the line item. Assigned by the system. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


6767
6768
6769
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6767

def line_item_id
  @line_item_id
end

#line_item_typeString

Required. Immutable. The type of the line item. Corresponds to the JSON property lineItemType

Returns:

  • (String)


6772
6773
6774
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6772

def line_item_type
  @line_item_type
end

#mobile_appGoogle::Apis::DisplayvideoV2::MobileApp

A mobile app promoted by a mobile app install line item. Corresponds to the JSON property mobileApp



6777
6778
6779
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6777

def mobile_app
  @mobile_app
end

#nameString

Output only. The resource name of the line item. Corresponds to the JSON property name

Returns:

  • (String)


6782
6783
6784
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6782

def name
  @name
end

#optimize_fixed_biddingBoolean Also known as: optimize_fixed_bidding?

Optional. Whether to enable DV360's bid optimization for fixed bid line items. By default, DV360 optimizes your fixed bid by automatically lowering bids for impressions that are less likely to perform well. This optimization is enabled by default (value is true). When this field is set to false, this optimization is disabled, and the bid will not be lowered for any reason. This setting only applies to line items with a bidding_strategy of type FIXED_BID. Corresponds to the JSON property optimizeFixedBidding

Returns:

  • (Boolean)


6793
6794
6795
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6793

def optimize_fixed_bidding
  @optimize_fixed_bidding
end

#pacingGoogle::Apis::DisplayvideoV2::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



6799
6800
6801
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6799

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV2::PartnerCost>

The partner costs associated with the line item. If absent or empty in CreateLineItem method, the newly created line item will inherit partner costs from its parent insertion order. Corresponds to the JSON property partnerCosts



6806
6807
6808
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6806

def partner_costs
  @partner_costs
end

#partner_revenue_modelGoogle::Apis::DisplayvideoV2::PartnerRevenueModel

Settings that control how partner revenue is calculated. Corresponds to the JSON property partnerRevenueModel



6811
6812
6813
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6811

def partner_revenue_model
  @partner_revenue_model
end

#reservation_typeString

Output only. The reservation type of the line item. Corresponds to the JSON property reservationType

Returns:

  • (String)


6816
6817
6818
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6816

def reservation_type
  @reservation_type
end

#targeting_expansionGoogle::Apis::DisplayvideoV2::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



6822
6823
6824
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6822

def targeting_expansion
  @targeting_expansion
end

#update_timeString

Output only. The timestamp when the line item was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


6828
6829
6830
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6828

def update_time
  @update_time
end

#warning_messagesArray<String>

Output only. The warning messages generated by the line item. These warnings do not block saving the line item, but some may block the line item from running. Corresponds to the JSON property warningMessages

Returns:

  • (Array<String>)


6835
6836
6837
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6835

def warning_messages
  @warning_messages
end

#youtube_and_partners_settingsGoogle::Apis::DisplayvideoV2::YoutubeAndPartnersSettings

Settings for YouTube and Partners line items. Corresponds to the JSON property youtubeAndPartnersSettings



6840
6841
6842
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6840

def youtube_and_partners_settings
  @youtube_and_partners_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 6847

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting)
  @creative_ids = args[:creative_ids] if args.key?(:creative_ids)
  @demand_gen_settings = args[:demand_gen_settings] if args.key?(:demand_gen_settings)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exclude_new_exchanges = args[:exclude_new_exchanges] if args.key?(:exclude_new_exchanges)
  @flight = args[:flight] if args.key?(:flight)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @line_item_type = args[:line_item_type] if args.key?(:line_item_type)
  @mobile_app = args[:mobile_app] if args.key?(:mobile_app)
  @name = args[:name] if args.key?(:name)
  @optimize_fixed_bidding = args[:optimize_fixed_bidding] if args.key?(:optimize_fixed_bidding)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @partner_revenue_model = args[:partner_revenue_model] if args.key?(:partner_revenue_model)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
  @update_time = args[:update_time] if args.key?(:update_time)
  @warning_messages = args[:warning_messages] if args.key?(:warning_messages)
  @youtube_and_partners_settings = args[:youtube_and_partners_settings] if args.key?(:youtube_and_partners_settings)
end