Class: Google::Apis::DisplayvideoV2::ListCreativesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCreativesResponse

Returns a new instance of ListCreativesResponse.



7190
7191
7192
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creativesArray<Google::Apis::DisplayvideoV2::Creative>

The list of creatives. This list will be absent if empty. Corresponds to the JSON property creatives



7180
7181
7182
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7180

def creatives
  @creatives
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCreativesRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7188
7189
7190
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7188

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7195
7196
7197
7198
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7195

def update!(**args)
  @creatives = args[:creatives] if args.key?(:creatives)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end