Class: Google::Apis::DisplayvideoV2::ListCustomBiddingScriptsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCustomBiddingScriptsResponse

Returns a new instance of ListCustomBiddingScriptsResponse.



7248
7249
7250
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_bidding_scriptsArray<Google::Apis::DisplayvideoV2::CustomBiddingScript>

The list of custom bidding scripts. This list will be absent if empty. Corresponds to the JSON property customBiddingScripts



7238
7239
7240
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7238

def custom_bidding_scripts
  @custom_bidding_scripts
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCustomBiddingScriptsRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7246
7247
7248
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7246

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7253
7254
7255
7256
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7253

def update!(**args)
  @custom_bidding_scripts = args[:custom_bidding_scripts] if args.key?(:custom_bidding_scripts)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end