Class: Google::Apis::DisplayvideoV2::ListInvoicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInvoicesResponse

Returns a new instance of ListInvoicesResponse.



7438
7439
7440
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#invoicesArray<Google::Apis::DisplayvideoV2::Invoice>

The list of invoices. This list will be absent if empty. Corresponds to the JSON property invoices



7428
7429
7430
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7428

def invoices
  @invoices
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListInvoices method to retrieve the next page of results. This token will be absent if there are no more invoices to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7436
7437
7438
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7436

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7443
7444
7445
7446
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7443

def update!(**args)
  @invoices = args[:invoices] if args.key?(:invoices)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end