Class: Google::Apis::DisplayvideoV2::ListInvoicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::ListInvoicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Instance Attribute Summary collapse
-
#invoices ⇒ Array<Google::Apis::DisplayvideoV2::Invoice>
The list of invoices.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInvoicesResponse
constructor
A new instance of ListInvoicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInvoicesResponse
Returns a new instance of ListInvoicesResponse.
7429 7430 7431 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#invoices ⇒ Array<Google::Apis::DisplayvideoV2::Invoice>
The list of invoices. This list will be absent if empty.
Corresponds to the JSON property invoices
7419 7420 7421 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7419 def invoices @invoices end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListInvoices method to retrieve
the next page of results. This token will be absent if there are no more
invoices to return.
Corresponds to the JSON property nextPageToken
7427 7428 7429 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7427 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7434 7435 7436 7437 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7434 def update!(**args) @invoices = args[:invoices] if args.key?(:invoices) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |