Class: Google::Apis::DisplayvideoV2::ListUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::ListUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#users ⇒ Array<Google::Apis::DisplayvideoV2::User>
The list of users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUsersResponse
constructor
A new instance of ListUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUsersResponse
Returns a new instance of ListUsersResponse.
7738 7739 7740 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListUsers method to retrieve the
next page of results. This token will be absent if there are no more results
to return.
Corresponds to the JSON property nextPageToken
7731 7732 7733 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7731 def next_page_token @next_page_token end |
#users ⇒ Array<Google::Apis::DisplayvideoV2::User>
The list of users. This list will be absent if empty.
Corresponds to the JSON property users
7736 7737 7738 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7736 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7743 7744 7745 7746 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7743 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @users = args[:users] if args.key?(:users) end |