Class: Google::Apis::DisplayvideoV2::ListUsersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUsersResponse

Returns a new instance of ListUsersResponse.



7729
7730
7731
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListUsers method to retrieve the next page of results. This token will be absent if there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7722
7723
7724
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7722

def next_page_token
  @next_page_token
end

#usersArray<Google::Apis::DisplayvideoV2::User>

The list of users. This list will be absent if empty. Corresponds to the JSON property users



7727
7728
7729
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7727

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7734
7735
7736
7737
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7734

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @users = args[:users] if args.key?(:users)
end