Class: Google::Apis::DisplayvideoV2::ManualTrigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single manual trigger in Display & Video 360. Warning: Line Items using manual triggers no longer serve in Display & Video 360. This resource will sunset on August 1, 2023. Read our feature deprecation announcement for more information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManualTrigger

Returns a new instance of ManualTrigger.



7963
7964
7965
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_duration_minutesFixnum

Required. The maximum duration of each activation in minutes. Must be between 1 and 360 inclusive. After this duration, the trigger will be automatically deactivated. Corresponds to the JSON property activationDurationMinutes

Returns:

  • (Fixnum)


7928
7929
7930
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7928

def activation_duration_minutes
  @activation_duration_minutes
end

#advertiser_idFixnum

Required. Immutable. The unique ID of the advertiser that the manual trigger belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7934
7935
7936
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7934

def advertiser_id
  @advertiser_id
end

#display_nameString

Required. The display name of the manual trigger. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


7940
7941
7942
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7940

def display_name
  @display_name
end

#latest_activation_timeString

Output only. The timestamp of the trigger's latest activation. Corresponds to the JSON property latestActivationTime

Returns:

  • (String)


7945
7946
7947
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7945

def latest_activation_time
  @latest_activation_time
end

#nameString

Output only. The resource name of the manual trigger. Corresponds to the JSON property name

Returns:

  • (String)


7950
7951
7952
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7950

def name
  @name
end

#stateString

Output only. The state of the manual trigger. Will be set to the INACTIVE state upon creation. Corresponds to the JSON property state

Returns:

  • (String)


7956
7957
7958
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7956

def state
  @state
end

#trigger_idFixnum

Output only. The unique ID of the manual trigger. Corresponds to the JSON property triggerId

Returns:

  • (Fixnum)


7961
7962
7963
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7961

def trigger_id
  @trigger_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7968
7969
7970
7971
7972
7973
7974
7975
7976
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7968

def update!(**args)
  @activation_duration_minutes = args[:activation_duration_minutes] if args.key?(:activation_duration_minutes)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @latest_activation_time = args[:latest_activation_time] if args.key?(:latest_activation_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @trigger_id = args[:trigger_id] if args.key?(:trigger_id)
end