Class: Google::Apis::DisplayvideoV2::MastheadAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Details for a Masthead Ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MastheadAd

Returns a new instance of MastheadAd.



8041
8042
8043
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoplay_video_durationString

The duration of time the video will autoplay. Corresponds to the JSON property autoplayVideoDuration

Returns:

  • (String)


7986
7987
7988
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7986

def autoplay_video_duration
  @autoplay_video_duration
end

#autoplay_video_start_millisecondFixnum

The amount of time in milliseconds after which the video will start to play. Corresponds to the JSON property autoplayVideoStartMillisecond

Returns:

  • (Fixnum)


7991
7992
7993
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7991

def autoplay_video_start_millisecond
  @autoplay_video_start_millisecond
end

#call_to_action_button_labelString

The text on the call-to-action button. Corresponds to the JSON property callToActionButtonLabel

Returns:

  • (String)


7996
7997
7998
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 7996

def call_to_action_button_label
  @call_to_action_button_label
end

#call_to_action_final_urlString

The destination URL for the call-to-action button. Corresponds to the JSON property callToActionFinalUrl

Returns:

  • (String)


8001
8002
8003
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8001

def call_to_action_final_url
  @call_to_action_final_url
end

#call_to_action_tracking_urlString

The tracking URL for the call-to-action button. Corresponds to the JSON property callToActionTrackingUrl

Returns:

  • (String)


8006
8007
8008
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8006

def call_to_action_tracking_url
  @call_to_action_tracking_url
end

#companion_youtube_videosArray<Google::Apis::DisplayvideoV2::YoutubeVideoDetails>

The videos that appear next to the Masthead Ad on desktop. Can be no more than two. Corresponds to the JSON property companionYoutubeVideos



8012
8013
8014
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8012

def companion_youtube_videos
  @companion_youtube_videos
end

#descriptionString

The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


8017
8018
8019
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8017

def description
  @description
end

#headlineString

The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


8022
8023
8024
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8022

def headline
  @headline
end

#show_channel_artBoolean Also known as: show_channel_art?

Whether to show a background or banner that appears at the top of a YouTube page. Corresponds to the JSON property showChannelArt

Returns:

  • (Boolean)


8028
8029
8030
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8028

def show_channel_art
  @show_channel_art
end

#videoGoogle::Apis::DisplayvideoV2::YoutubeVideoDetails

Details of a YouTube video. Corresponds to the JSON property video



8034
8035
8036
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8034

def video
  @video
end

#video_aspect_ratioString

The aspect ratio of the autoplaying YouTube video on the Masthead. Corresponds to the JSON property videoAspectRatio

Returns:

  • (String)


8039
8040
8041
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8039

def video_aspect_ratio
  @video_aspect_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8046

def update!(**args)
  @autoplay_video_duration = args[:autoplay_video_duration] if args.key?(:autoplay_video_duration)
  @autoplay_video_start_millisecond = args[:autoplay_video_start_millisecond] if args.key?(:autoplay_video_start_millisecond)
  @call_to_action_button_label = args[:call_to_action_button_label] if args.key?(:call_to_action_button_label)
  @call_to_action_final_url = args[:call_to_action_final_url] if args.key?(:call_to_action_final_url)
  @call_to_action_tracking_url = args[:call_to_action_tracking_url] if args.key?(:call_to_action_tracking_url)
  @companion_youtube_videos = args[:companion_youtube_videos] if args.key?(:companion_youtube_videos)
  @description = args[:description] if args.key?(:description)
  @headline = args[:headline] if args.key?(:headline)
  @show_channel_art = args[:show_channel_art] if args.key?(:show_channel_art)
  @video = args[:video] if args.key?(:video)
  @video_aspect_ratio = args[:video_aspect_ratio] if args.key?(:video_aspect_ratio)
end