Class: Google::Apis::DisplayvideoV2::MobileApp
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::MobileApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
A mobile app promoted by a mobile app install line item.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Required.
-
#display_name ⇒ String
Output only.
-
#platform ⇒ String
Output only.
-
#publisher ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileApp
constructor
A new instance of MobileApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileApp
Returns a new instance of MobileApp.
8172 8173 8174 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Required. The ID of the app provided by the platform store. Android apps are
identified by the bundle ID used by Android's Play store, such as com.google.
android.gm. iOS apps are identified by a nine-digit app ID used by Apple's
App store, such as 422689480.
Corresponds to the JSON property appId
8155 8156 8157 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8155 def app_id @app_id end |
#display_name ⇒ String
Output only. The app name.
Corresponds to the JSON property displayName
8160 8161 8162 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8160 def display_name @display_name end |
#platform ⇒ String
Output only. The app platform.
Corresponds to the JSON property platform
8165 8166 8167 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8165 def platform @platform end |
#publisher ⇒ String
Output only. The app publisher.
Corresponds to the JSON property publisher
8170 8171 8172 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8170 def publisher @publisher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8177 8178 8179 8180 8181 8182 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8177 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @display_name = args[:display_name] if args.key?(:display_name) @platform = args[:platform] if args.key?(:platform) @publisher = args[:publisher] if args.key?(:publisher) end |