Class: Google::Apis::DisplayvideoV2::MobileApp
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::MobileApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
A mobile app promoted by a mobile app install line item.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Required.
-
#display_name ⇒ String
Output only.
-
#platform ⇒ String
Output only.
-
#publisher ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileApp
constructor
A new instance of MobileApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileApp
Returns a new instance of MobileApp.
8163 8164 8165 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Required. The ID of the app provided by the platform store. Android apps are
identified by the bundle ID used by Android's Play store, such as com.google.
android.gm. iOS apps are identified by a nine-digit app ID used by Apple's
App store, such as 422689480.
Corresponds to the JSON property appId
8146 8147 8148 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8146 def app_id @app_id end |
#display_name ⇒ String
Output only. The app name.
Corresponds to the JSON property displayName
8151 8152 8153 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8151 def display_name @display_name end |
#platform ⇒ String
Output only. The app platform.
Corresponds to the JSON property platform
8156 8157 8158 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8156 def platform @platform end |
#publisher ⇒ String
Output only. The app publisher.
Corresponds to the JSON property publisher
8161 8162 8163 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8161 def publisher @publisher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8168 8169 8170 8171 8172 8173 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8168 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @display_name = args[:display_name] if args.key?(:display_name) @platform = args[:platform] if args.key?(:platform) @publisher = args[:publisher] if args.key?(:publisher) end |