Class: Google::Apis::DisplayvideoV2::Partner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single partner in Display & Video 360 (DV360).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Partner

Returns a new instance of Partner.



8807
8808
8809
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_server_configGoogle::Apis::DisplayvideoV2::PartnerAdServerConfig

Ad server related settings of a partner. Corresponds to the JSON property adServerConfig



8763
8764
8765
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8763

def ad_server_config
  @ad_server_config
end

#data_access_configGoogle::Apis::DisplayvideoV2::PartnerDataAccessConfig

Settings that control how partner related data may be accessed. Corresponds to the JSON property dataAccessConfig



8768
8769
8770
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8768

def data_access_config
  @data_access_config
end

#display_nameString

The display name of the partner. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


8774
8775
8776
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8774

def display_name
  @display_name
end

#entity_statusString

Output only. The status of the partner. Corresponds to the JSON property entityStatus

Returns:

  • (String)


8779
8780
8781
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8779

def entity_status
  @entity_status
end

#exchange_configGoogle::Apis::DisplayvideoV2::ExchangeConfig

Settings that control which exchanges are enabled for a partner. Corresponds to the JSON property exchangeConfig



8784
8785
8786
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8784

def exchange_config
  @exchange_config
end

#general_configGoogle::Apis::DisplayvideoV2::PartnerGeneralConfig

General settings of a partner. Corresponds to the JSON property generalConfig



8789
8790
8791
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8789

def general_config
  @general_config
end

#nameString

Output only. The resource name of the partner. Corresponds to the JSON property name

Returns:

  • (String)


8794
8795
8796
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8794

def name
  @name
end

#partner_idFixnum

Output only. The unique ID of the partner. Assigned by the system. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


8799
8800
8801
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8799

def partner_id
  @partner_id
end

#update_timeString

Output only. The timestamp when the partner was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


8805
8806
8807
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8805

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 8812

def update!(**args)
  @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config)
  @data_access_config = args[:data_access_config] if args.key?(:data_access_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exchange_config = args[:exchange_config] if args.key?(:exchange_config)
  @general_config = args[:general_config] if args.key?(:general_config)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end