Class: Google::Apis::DisplayvideoV2::TargetingExpansionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::TargetingExpansionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Settings that control the optimized targeting settings of the line item.
Instance Attribute Summary collapse
-
#exclude_demographic_expansion ⇒ Boolean
(also: #exclude_demographic_expansion?)
Optional.
-
#exclude_first_party_audience ⇒ Boolean
(also: #exclude_first_party_audience?)
Whether to exclude first-party audiences from use in targeting expansion.
-
#targeting_expansion_level ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetingExpansionConfig
constructor
A new instance of TargetingExpansionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetingExpansionConfig
Returns a new instance of TargetingExpansionConfig.
10041 10042 10043 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_demographic_expansion ⇒ Boolean Also known as: exclude_demographic_expansion?
Optional. Whether to exclude demographic expansion for Optimized Targeting.
This field can only be set for Demand Gen ad groups.
Corresponds to the JSON property excludeDemographicExpansion
10016 10017 10018 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10016 def exclude_demographic_expansion @exclude_demographic_expansion end |
#exclude_first_party_audience ⇒ Boolean Also known as: exclude_first_party_audience?
Whether to exclude first-party audiences from use in targeting expansion. This
field was deprecated with the launch of optimized targeting. This field will be set to false. If this
field is set to true when deprecated, all positive first-party audience
targeting assigned to this line item will be replaced with negative targeting
of the same first-party audiences to ensure the continued exclusion of those
audiences.
Corresponds to the JSON property excludeFirstPartyAudience
10028 10029 10030 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10028 def exclude_first_party_audience @exclude_first_party_audience end |
#targeting_expansion_level ⇒ String
Required. Whether optimized targeting is turned on. This field supports the
following values: * NO_EXPANSION: optimized targeting is turned off *
LEAST_EXPANSION: optimized targeting is turned on If this field is set to any
other value, it will automatically be set to LEAST_EXPANSION. NO_EXPANSION
will be the default value for the field and will be automatically assigned if
you do not set the field.
Corresponds to the JSON property targetingExpansionLevel
10039 10040 10041 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10039 def targeting_expansion_level @targeting_expansion_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10046 10047 10048 10049 10050 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10046 def update!(**args) @exclude_demographic_expansion = args[:exclude_demographic_expansion] if args.key?(:exclude_demographic_expansion) @exclude_first_party_audience = args[:exclude_first_party_audience] if args.key?(:exclude_first_party_audience) @targeting_expansion_level = args[:targeting_expansion_level] if args.key?(:targeting_expansion_level) end |