Class: Google::Apis::DisplayvideoV2::ThirdPartyUrl
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::ThirdPartyUrl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Tracking URLs from third parties to track interactions with an audio or a video creative.
Instance Attribute Summary collapse
-
#type ⇒ String
Optional.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ThirdPartyUrl
constructor
A new instance of ThirdPartyUrl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ThirdPartyUrl
Returns a new instance of ThirdPartyUrl.
10432 10433 10434 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#type ⇒ String
Optional. The type of interaction needs to be tracked by the tracking URL
Corresponds to the JSON property type
10423 10424 10425 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10423 def type @type end |
#url ⇒ String
Optional. Tracking URL used to track the interaction. Provide a URL with
optional path or query string, beginning with https:. For example, https://
www.example.com/path
Corresponds to the JSON property url
10430 10431 10432 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10430 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10437 10438 10439 10440 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10437 def update!(**args) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |