Class: Google::Apis::DisplayvideoV2::Transcode
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::Transcode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Represents information about the transcoded audio or video file.
Instance Attribute Summary collapse
-
#audio_bit_rate_kbps ⇒ Fixnum
Optional.
-
#audio_sample_rate_hz ⇒ Fixnum
Optional.
-
#bit_rate_kbps ⇒ Fixnum
Optional.
-
#dimensions ⇒ Google::Apis::DisplayvideoV2::Dimensions
Dimensions.
-
#file_size_bytes ⇒ Fixnum
Optional.
-
#frame_rate ⇒ Float
Optional.
-
#mime_type ⇒ String
Optional.
-
#name ⇒ String
Optional.
-
#transcoded ⇒ Boolean
(also: #transcoded?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Transcode
constructor
A new instance of Transcode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Transcode
Returns a new instance of Transcode.
10642 10643 10644 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_bit_rate_kbps ⇒ Fixnum
Optional. The bit rate for the audio stream of the transcoded video, or the
bit rate for the transcoded audio, in kilobits per second.
Corresponds to the JSON property audioBitRateKbps
10597 10598 10599 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10597 def audio_bit_rate_kbps @audio_bit_rate_kbps end |
#audio_sample_rate_hz ⇒ Fixnum
Optional. The sample rate for the audio stream of the transcoded video, or the
sample rate for the transcoded audio, in hertz.
Corresponds to the JSON property audioSampleRateHz
10603 10604 10605 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10603 def audio_sample_rate_hz @audio_sample_rate_hz end |
#bit_rate_kbps ⇒ Fixnum
Optional. The transcoding bit rate of the transcoded video, in kilobits per
second.
Corresponds to the JSON property bitRateKbps
10609 10610 10611 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10609 def bit_rate_kbps @bit_rate_kbps end |
#dimensions ⇒ Google::Apis::DisplayvideoV2::Dimensions
Dimensions.
Corresponds to the JSON property dimensions
10614 10615 10616 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10614 def dimensions @dimensions end |
#file_size_bytes ⇒ Fixnum
Optional. The size of the transcoded file, in bytes.
Corresponds to the JSON property fileSizeBytes
10619 10620 10621 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10619 def file_size_bytes @file_size_bytes end |
#frame_rate ⇒ Float
Optional. The frame rate of the transcoded video, in frames per second.
Corresponds to the JSON property frameRate
10624 10625 10626 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10624 def frame_rate @frame_rate end |
#mime_type ⇒ String
Optional. The MIME type of the transcoded file.
Corresponds to the JSON property mimeType
10629 10630 10631 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10629 def mime_type @mime_type end |
#name ⇒ String
Optional. The name of the transcoded file.
Corresponds to the JSON property name
10634 10635 10636 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10634 def name @name end |
#transcoded ⇒ Boolean Also known as: transcoded?
Optional. Indicates if the transcoding was successful.
Corresponds to the JSON property transcoded
10639 10640 10641 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10639 def transcoded @transcoded end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10647 10648 10649 10650 10651 10652 10653 10654 10655 10656 10657 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10647 def update!(**args) @audio_bit_rate_kbps = args[:audio_bit_rate_kbps] if args.key?(:audio_bit_rate_kbps) @audio_sample_rate_hz = args[:audio_sample_rate_hz] if args.key?(:audio_sample_rate_hz) @bit_rate_kbps = args[:bit_rate_kbps] if args.key?(:bit_rate_kbps) @dimensions = args[:dimensions] if args.key?(:dimensions) @file_size_bytes = args[:file_size_bytes] if args.key?(:file_size_bytes) @frame_rate = args[:frame_rate] if args.key?(:frame_rate) @mime_type = args[:mime_type] if args.key?(:mime_type) @name = args[:name] if args.key?(:name) @transcoded = args[:transcoded] if args.key?(:transcoded) end |