Class: Google::Apis::DisplayvideoV2::Transcode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Represents information about the transcoded audio or video file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Transcode

Returns a new instance of Transcode.



10622
10623
10624
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bit_rate_kbpsFixnum

Optional. The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second. Corresponds to the JSON property audioBitRateKbps

Returns:

  • (Fixnum)


10577
10578
10579
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10577

def audio_bit_rate_kbps
  @audio_bit_rate_kbps
end

#audio_sample_rate_hzFixnum

Optional. The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz. Corresponds to the JSON property audioSampleRateHz

Returns:

  • (Fixnum)


10583
10584
10585
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10583

def audio_sample_rate_hz
  @audio_sample_rate_hz
end

#bit_rate_kbpsFixnum

Optional. The transcoding bit rate of the transcoded video, in kilobits per second. Corresponds to the JSON property bitRateKbps

Returns:

  • (Fixnum)


10589
10590
10591
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10589

def bit_rate_kbps
  @bit_rate_kbps
end

#dimensionsGoogle::Apis::DisplayvideoV2::Dimensions

Dimensions. Corresponds to the JSON property dimensions



10594
10595
10596
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10594

def dimensions
  @dimensions
end

#file_size_bytesFixnum

Optional. The size of the transcoded file, in bytes. Corresponds to the JSON property fileSizeBytes

Returns:

  • (Fixnum)


10599
10600
10601
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10599

def file_size_bytes
  @file_size_bytes
end

#frame_rateFloat

Optional. The frame rate of the transcoded video, in frames per second. Corresponds to the JSON property frameRate

Returns:

  • (Float)


10604
10605
10606
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10604

def frame_rate
  @frame_rate
end

#mime_typeString

Optional. The MIME type of the transcoded file. Corresponds to the JSON property mimeType

Returns:

  • (String)


10609
10610
10611
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10609

def mime_type
  @mime_type
end

#nameString

Optional. The name of the transcoded file. Corresponds to the JSON property name

Returns:

  • (String)


10614
10615
10616
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10614

def name
  @name
end

#transcodedBoolean Also known as: transcoded?

Optional. Indicates if the transcoding was successful. Corresponds to the JSON property transcoded

Returns:

  • (Boolean)


10619
10620
10621
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10619

def transcoded
  @transcoded
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10627
10628
10629
10630
10631
10632
10633
10634
10635
10636
10637
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10627

def update!(**args)
  @audio_bit_rate_kbps = args[:audio_bit_rate_kbps] if args.key?(:audio_bit_rate_kbps)
  @audio_sample_rate_hz = args[:audio_sample_rate_hz] if args.key?(:audio_sample_rate_hz)
  @bit_rate_kbps = args[:bit_rate_kbps] if args.key?(:bit_rate_kbps)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @file_size_bytes = args[:file_size_bytes] if args.key?(:file_size_bytes)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @name = args[:name] if args.key?(:name)
  @transcoded = args[:transcoded] if args.key?(:transcoded)
end