Class: Google::Apis::DisplayvideoV2::Transcode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Represents information about the transcoded audio or video file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Transcode

Returns a new instance of Transcode.



10613
10614
10615
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bit_rate_kbpsFixnum

Optional. The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second. Corresponds to the JSON property audioBitRateKbps

Returns:

  • (Fixnum)


10568
10569
10570
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10568

def audio_bit_rate_kbps
  @audio_bit_rate_kbps
end

#audio_sample_rate_hzFixnum

Optional. The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz. Corresponds to the JSON property audioSampleRateHz

Returns:

  • (Fixnum)


10574
10575
10576
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10574

def audio_sample_rate_hz
  @audio_sample_rate_hz
end

#bit_rate_kbpsFixnum

Optional. The transcoding bit rate of the transcoded video, in kilobits per second. Corresponds to the JSON property bitRateKbps

Returns:

  • (Fixnum)


10580
10581
10582
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10580

def bit_rate_kbps
  @bit_rate_kbps
end

#dimensionsGoogle::Apis::DisplayvideoV2::Dimensions

Dimensions. Corresponds to the JSON property dimensions



10585
10586
10587
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10585

def dimensions
  @dimensions
end

#file_size_bytesFixnum

Optional. The size of the transcoded file, in bytes. Corresponds to the JSON property fileSizeBytes

Returns:

  • (Fixnum)


10590
10591
10592
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10590

def file_size_bytes
  @file_size_bytes
end

#frame_rateFloat

Optional. The frame rate of the transcoded video, in frames per second. Corresponds to the JSON property frameRate

Returns:

  • (Float)


10595
10596
10597
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10595

def frame_rate
  @frame_rate
end

#mime_typeString

Optional. The MIME type of the transcoded file. Corresponds to the JSON property mimeType

Returns:

  • (String)


10600
10601
10602
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10600

def mime_type
  @mime_type
end

#nameString

Optional. The name of the transcoded file. Corresponds to the JSON property name

Returns:

  • (String)


10605
10606
10607
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10605

def name
  @name
end

#transcodedBoolean Also known as: transcoded?

Optional. Indicates if the transcoding was successful. Corresponds to the JSON property transcoded

Returns:

  • (Boolean)


10610
10611
10612
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10610

def transcoded
  @transcoded
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10618
10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 10618

def update!(**args)
  @audio_bit_rate_kbps = args[:audio_bit_rate_kbps] if args.key?(:audio_bit_rate_kbps)
  @audio_sample_rate_hz = args[:audio_sample_rate_hz] if args.key?(:audio_sample_rate_hz)
  @bit_rate_kbps = args[:bit_rate_kbps] if args.key?(:bit_rate_kbps)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @file_size_bytes = args[:file_size_bytes] if args.key?(:file_size_bytes)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @name = args[:name] if args.key?(:name)
  @transcoded = args[:transcoded] if args.key?(:transcoded)
end