Class: Google::Apis::DisplayvideoV2::YoutubeAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::YoutubeAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
A single YouTube ad group associated with a YouTube and Partners line item.
Instance Attribute Summary collapse
-
#ad_group_format ⇒ String
The format of the ads in the ad group.
-
#ad_group_id ⇒ Fixnum
The unique ID of the ad group.
-
#advertiser_id ⇒ Fixnum
The unique ID of the advertiser the ad group belongs to.
-
#bidding_strategy ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersBiddingStrategy
Settings that control the bid strategy for YouTube and Partners resources.
-
#display_name ⇒ String
The display name of the ad group.
-
#entity_status ⇒ String
Controls whether or not the ad group can spend its budget and bid on inventory.
-
#line_item_id ⇒ Fixnum
The unique ID of the line item that the ad group belongs to.
-
#name ⇒ String
The resource name of the ad group.
-
#product_feed_data ⇒ Google::Apis::DisplayvideoV2::ProductFeedData
The details of product feed.
-
#targeting_expansion ⇒ Google::Apis::DisplayvideoV2::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
-
#youtube_ad_ids ⇒ Array<Fixnum>
The IDs of the youtube_ad_group_ad resources associated with the ad group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeAdGroup
constructor
A new instance of YoutubeAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeAdGroup
Returns a new instance of YoutubeAdGroup.
11198 11199 11200 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_format ⇒ String
The format of the ads in the ad group.
Corresponds to the JSON property adGroupFormat
11142 11143 11144 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11142 def ad_group_format @ad_group_format end |
#ad_group_id ⇒ Fixnum
The unique ID of the ad group. Assigned by the system.
Corresponds to the JSON property adGroupId
11147 11148 11149 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11147 def ad_group_id @ad_group_id end |
#advertiser_id ⇒ Fixnum
The unique ID of the advertiser the ad group belongs to.
Corresponds to the JSON property advertiserId
11152 11153 11154 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11152 def advertiser_id @advertiser_id end |
#bidding_strategy ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersBiddingStrategy
Settings that control the bid strategy for YouTube and Partners resources.
Corresponds to the JSON property biddingStrategy
11157 11158 11159 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11157 def bidding_strategy @bidding_strategy end |
#display_name ⇒ String
The display name of the ad group. Must be UTF-8 encoded with a maximum size of
255 bytes.
Corresponds to the JSON property displayName
11163 11164 11165 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11163 def display_name @display_name end |
#entity_status ⇒ String
Controls whether or not the ad group can spend its budget and bid on inventory.
If the ad group's parent line item is not active, the ad group can't spend
its budget even if its own status is ENTITY_STATUS_ACTIVE.
Corresponds to the JSON property entityStatus
11170 11171 11172 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11170 def entity_status @entity_status end |
#line_item_id ⇒ Fixnum
The unique ID of the line item that the ad group belongs to.
Corresponds to the JSON property lineItemId
11175 11176 11177 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11175 def line_item_id @line_item_id end |
#name ⇒ String
The resource name of the ad group.
Corresponds to the JSON property name
11180 11181 11182 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11180 def name @name end |
#product_feed_data ⇒ Google::Apis::DisplayvideoV2::ProductFeedData
The details of product feed.
Corresponds to the JSON property productFeedData
11185 11186 11187 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11185 def product_feed_data @product_feed_data end |
#targeting_expansion ⇒ Google::Apis::DisplayvideoV2::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
Corresponds to the JSON property targetingExpansion
11191 11192 11193 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11191 def targeting_expansion @targeting_expansion end |
#youtube_ad_ids ⇒ Array<Fixnum>
The IDs of the youtube_ad_group_ad resources associated with the ad group.
Corresponds to the JSON property youtubeAdIds
11196 11197 11198 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11196 def youtube_ad_ids @youtube_ad_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11203 11204 11205 11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11203 def update!(**args) @ad_group_format = args[:ad_group_format] if args.key?(:ad_group_format) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @line_item_id = args[:line_item_id] if args.key?(:line_item_id) @name = args[:name] if args.key?(:name) @product_feed_data = args[:product_feed_data] if args.key?(:product_feed_data) @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion) @youtube_ad_ids = args[:youtube_ad_ids] if args.key?(:youtube_ad_ids) end |