Class: Google::Apis::DisplayvideoV2::YoutubeAdGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single YouTube ad group associated with a YouTube and Partners line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAdGroup

Returns a new instance of YoutubeAdGroup.



11176
11177
11178
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_formatString

The format of the ads in the ad group. Corresponds to the JSON property adGroupFormat

Returns:

  • (String)


11120
11121
11122
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11120

def ad_group_format
  @ad_group_format
end

#ad_group_idFixnum

The unique ID of the ad group. Assigned by the system. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


11125
11126
11127
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11125

def ad_group_id
  @ad_group_id
end

#advertiser_idFixnum

The unique ID of the advertiser the ad group belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


11130
11131
11132
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11130

def advertiser_id
  @advertiser_id
end

#bidding_strategyGoogle::Apis::DisplayvideoV2::YoutubeAndPartnersBiddingStrategy

Settings that control the bid strategy for YouTube and Partners resources. Corresponds to the JSON property biddingStrategy



11135
11136
11137
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11135

def bidding_strategy
  @bidding_strategy
end

#display_nameString

The display name of the ad group. Must be UTF-8 encoded with a maximum size of 255 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


11141
11142
11143
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11141

def display_name
  @display_name
end

#entity_statusString

Controls whether or not the ad group can spend its budget and bid on inventory. If the ad group's parent line item is not active, the ad group can't spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


11148
11149
11150
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11148

def entity_status
  @entity_status
end

#line_item_idFixnum

The unique ID of the line item that the ad group belongs to. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


11153
11154
11155
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11153

def line_item_id
  @line_item_id
end

#nameString

The resource name of the ad group. Corresponds to the JSON property name

Returns:

  • (String)


11158
11159
11160
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11158

def name
  @name
end

#product_feed_dataGoogle::Apis::DisplayvideoV2::ProductFeedData

The details of product feed. Corresponds to the JSON property productFeedData



11163
11164
11165
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11163

def product_feed_data
  @product_feed_data
end

#targeting_expansionGoogle::Apis::DisplayvideoV2::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



11169
11170
11171
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11169

def targeting_expansion
  @targeting_expansion
end

#youtube_ad_idsArray<Fixnum>

The IDs of the youtube_ad_group_ad resources associated with the ad group. Corresponds to the JSON property youtubeAdIds

Returns:

  • (Array<Fixnum>)


11174
11175
11176
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11174

def youtube_ad_ids
  @youtube_ad_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
11193
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11181

def update!(**args)
  @ad_group_format = args[:ad_group_format] if args.key?(:ad_group_format)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @name = args[:name] if args.key?(:name)
  @product_feed_data = args[:product_feed_data] if args.key?(:product_feed_data)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
  @youtube_ad_ids = args[:youtube_ad_ids] if args.key?(:youtube_ad_ids)
end