Class: Google::Apis::DisplayvideoV2::YoutubeAdGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

A single YouTube ad group associated with a YouTube and Partners line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAdGroup

Returns a new instance of YoutubeAdGroup.



11169
11170
11171
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_formatString

The format of the ads in the ad group. Corresponds to the JSON property adGroupFormat

Returns:

  • (String)


11113
11114
11115
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11113

def ad_group_format
  @ad_group_format
end

#ad_group_idFixnum

The unique ID of the ad group. Assigned by the system. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


11118
11119
11120
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11118

def ad_group_id
  @ad_group_id
end

#advertiser_idFixnum

The unique ID of the advertiser the ad group belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


11123
11124
11125
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11123

def advertiser_id
  @advertiser_id
end

#bidding_strategyGoogle::Apis::DisplayvideoV2::YoutubeAndPartnersBiddingStrategy

Settings that control the bid strategy for YouTube and Partners resources. Corresponds to the JSON property biddingStrategy



11128
11129
11130
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11128

def bidding_strategy
  @bidding_strategy
end

#display_nameString

The display name of the ad group. Must be UTF-8 encoded with a maximum size of 255 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


11134
11135
11136
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11134

def display_name
  @display_name
end

#entity_statusString

Controls whether or not the ad group can spend its budget and bid on inventory. If the ad group's parent line item is not active, the ad group can't spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


11141
11142
11143
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11141

def entity_status
  @entity_status
end

#line_item_idFixnum

The unique ID of the line item that the ad group belongs to. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


11146
11147
11148
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11146

def line_item_id
  @line_item_id
end

#nameString

The resource name of the ad group. Corresponds to the JSON property name

Returns:

  • (String)


11151
11152
11153
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11151

def name
  @name
end

#product_feed_dataGoogle::Apis::DisplayvideoV2::ProductFeedData

The details of product feed. Corresponds to the JSON property productFeedData



11156
11157
11158
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11156

def product_feed_data
  @product_feed_data
end

#targeting_expansionGoogle::Apis::DisplayvideoV2::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



11162
11163
11164
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11162

def targeting_expansion
  @targeting_expansion
end

#youtube_ad_idsArray<Fixnum>

The IDs of the youtube_ad_group_ad resources associated with the ad group. Corresponds to the JSON property youtubeAdIds

Returns:

  • (Array<Fixnum>)


11167
11168
11169
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11167

def youtube_ad_ids
  @youtube_ad_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11174
11175
11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11174

def update!(**args)
  @ad_group_format = args[:ad_group_format] if args.key?(:ad_group_format)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @name = args[:name] if args.key?(:name)
  @product_feed_data = args[:product_feed_data] if args.key?(:product_feed_data)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
  @youtube_ad_ids = args[:youtube_ad_ids] if args.key?(:youtube_ad_ids)
end