Class: Google::Apis::DisplayvideoV2::YoutubeAndPartnersSettings
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV2::YoutubeAndPartnersSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb
Overview
Settings for YouTube and Partners line items.
Instance Attribute Summary collapse
-
#bidding_strategy ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersBiddingStrategy
Settings that control the bid strategy for YouTube and Partners resources.
-
#content_category ⇒ String
Output only.
-
#effective_content_category ⇒ String
Output only.
-
#inventory_source_settings ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersInventorySourceConfig
Settings that control what YouTube related inventories the YouTube and Partners line item will target.
-
#lead_form_id ⇒ Fixnum
Optional.
-
#linked_merchant_id ⇒ Fixnum
Optional.
-
#related_video_ids ⇒ Array<String>
Optional.
-
#target_frequency ⇒ Google::Apis::DisplayvideoV2::TargetFrequency
Setting that controls the average number of times the ads will show to the same person over a certain period of time.
-
#third_party_measurement_settings ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersThirdPartyMeasurementSettings
Settings that control what third-party vendors are measuring specific line item metrics.
-
#video_ad_inventory_control ⇒ Google::Apis::DisplayvideoV2::VideoAdInventoryControl
The video ad inventory control used in certain YouTube line item types.
-
#video_ad_sequence_settings ⇒ Google::Apis::DisplayvideoV2::VideoAdSequenceSettings
Settings related to VideoAdSequence.
-
#view_frequency_cap ⇒ Google::Apis::DisplayvideoV2::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeAndPartnersSettings
constructor
A new instance of YoutubeAndPartnersSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeAndPartnersSettings
Returns a new instance of YoutubeAndPartnersSettings.
11498 11499 11500 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bidding_strategy ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersBiddingStrategy
Settings that control the bid strategy for YouTube and Partners resources.
Corresponds to the JSON property biddingStrategy
11430 11431 11432 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11430 def bidding_strategy @bidding_strategy end |
#content_category ⇒ String
Output only. The kind of content on which the YouTube and Partners ads will be
shown. Warning: This field will be removed in the near future. Use
effective_content_category instead.
Corresponds to the JSON property contentCategory
11437 11438 11439 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11437 def content_category @content_category end |
#effective_content_category ⇒ String
Output only. The content category which takes effect when serving the line
item. When content category is set in both line item and advertiser, the
stricter one will take effect when serving the line item. New line items will
only inherit the advertiser level setting.
Corresponds to the JSON property effectiveContentCategory
11445 11446 11447 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11445 def effective_content_category @effective_content_category end |
#inventory_source_settings ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersInventorySourceConfig
Settings that control what YouTube related inventories the YouTube and
Partners line item will target.
Corresponds to the JSON property inventorySourceSettings
11451 11452 11453 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11451 def inventory_source_settings @inventory_source_settings end |
#lead_form_id ⇒ Fixnum
Optional. The ID of the form to generate leads.
Corresponds to the JSON property leadFormId
11456 11457 11458 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11456 def lead_form_id @lead_form_id end |
#linked_merchant_id ⇒ Fixnum
Optional. The ID of the Merchant Center account used to provide a product feed.
This Merchant Center account must already be linked to the advertiser.
Corresponds to the JSON property linkedMerchantId
11462 11463 11464 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11462 def linked_merchant_id @linked_merchant_id end |
#related_video_ids ⇒ Array<String>
Optional. The IDs of the videos appear below the primary video ad when the ad
is playing in the YouTube app on mobile devices.
Corresponds to the JSON property relatedVideoIds
11468 11469 11470 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11468 def @related_video_ids end |
#target_frequency ⇒ Google::Apis::DisplayvideoV2::TargetFrequency
Setting that controls the average number of times the ads will show to the
same person over a certain period of time.
Corresponds to the JSON property targetFrequency
11474 11475 11476 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11474 def target_frequency @target_frequency end |
#third_party_measurement_settings ⇒ Google::Apis::DisplayvideoV2::YoutubeAndPartnersThirdPartyMeasurementSettings
Settings that control what third-party vendors are measuring specific line
item metrics.
Corresponds to the JSON property thirdPartyMeasurementSettings
11480 11481 11482 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11480 def third_party_measurement_settings @third_party_measurement_settings end |
#video_ad_inventory_control ⇒ Google::Apis::DisplayvideoV2::VideoAdInventoryControl
The video ad inventory control used in certain YouTube line item types.
Corresponds to the JSON property videoAdInventoryControl
11485 11486 11487 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11485 def video_ad_inventory_control @video_ad_inventory_control end |
#video_ad_sequence_settings ⇒ Google::Apis::DisplayvideoV2::VideoAdSequenceSettings
Settings related to VideoAdSequence.
Corresponds to the JSON property videoAdSequenceSettings
11490 11491 11492 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11490 def video_ad_sequence_settings @video_ad_sequence_settings end |
#view_frequency_cap ⇒ Google::Apis::DisplayvideoV2::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property viewFrequencyCap
11496 11497 11498 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11496 def view_frequency_cap @view_frequency_cap end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11503 11504 11505 11506 11507 11508 11509 11510 11511 11512 11513 11514 11515 11516 |
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11503 def update!(**args) @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy) @content_category = args[:content_category] if args.key?(:content_category) @effective_content_category = args[:effective_content_category] if args.key?(:effective_content_category) @inventory_source_settings = args[:inventory_source_settings] if args.key?(:inventory_source_settings) @lead_form_id = args[:lead_form_id] if args.key?(:lead_form_id) @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id) @related_video_ids = args[:related_video_ids] if args.key?(:related_video_ids) @target_frequency = args[:target_frequency] if args.key?(:target_frequency) @third_party_measurement_settings = args[:third_party_measurement_settings] if args.key?(:third_party_measurement_settings) @video_ad_inventory_control = args[:video_ad_inventory_control] if args.key?(:video_ad_inventory_control) @video_ad_sequence_settings = args[:video_ad_sequence_settings] if args.key?(:video_ad_sequence_settings) @view_frequency_cap = args[:view_frequency_cap] if args.key?(:view_frequency_cap) end |