Class: Google::Apis::DisplayvideoV2::YoutubeAndPartnersSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v2/classes.rb,
lib/google/apis/displayvideo_v2/representations.rb,
lib/google/apis/displayvideo_v2/representations.rb

Overview

Settings for YouTube and Partners line items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAndPartnersSettings

Returns a new instance of YoutubeAndPartnersSettings.



11489
11490
11491
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bidding_strategyGoogle::Apis::DisplayvideoV2::YoutubeAndPartnersBiddingStrategy

Settings that control the bid strategy for YouTube and Partners resources. Corresponds to the JSON property biddingStrategy



11421
11422
11423
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11421

def bidding_strategy
  @bidding_strategy
end

#content_categoryString

Output only. The kind of content on which the YouTube and Partners ads will be shown. Warning: This field will be removed in the near future. Use effective_content_category instead. Corresponds to the JSON property contentCategory

Returns:

  • (String)


11428
11429
11430
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11428

def 
  @content_category
end

#effective_content_categoryString

Output only. The content category which takes effect when serving the line item. When content category is set in both line item and advertiser, the stricter one will take effect when serving the line item. New line items will only inherit the advertiser level setting. Corresponds to the JSON property effectiveContentCategory

Returns:

  • (String)


11436
11437
11438
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11436

def 
  @effective_content_category
end

#inventory_source_settingsGoogle::Apis::DisplayvideoV2::YoutubeAndPartnersInventorySourceConfig

Settings that control what YouTube related inventories the YouTube and Partners line item will target. Corresponds to the JSON property inventorySourceSettings



11442
11443
11444
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11442

def inventory_source_settings
  @inventory_source_settings
end

#lead_form_idFixnum

Optional. The ID of the form to generate leads. Corresponds to the JSON property leadFormId

Returns:

  • (Fixnum)


11447
11448
11449
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11447

def lead_form_id
  @lead_form_id
end

#linked_merchant_idFixnum

Optional. The ID of the Merchant Center account used to provide a product feed. This Merchant Center account must already be linked to the advertiser. Corresponds to the JSON property linkedMerchantId

Returns:

  • (Fixnum)


11453
11454
11455
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11453

def linked_merchant_id
  @linked_merchant_id
end

Optional. The IDs of the videos appear below the primary video ad when the ad is playing in the YouTube app on mobile devices. Corresponds to the JSON property relatedVideoIds

Returns:

  • (Array<String>)


11459
11460
11461
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11459

def related_video_ids
  @related_video_ids
end

#target_frequencyGoogle::Apis::DisplayvideoV2::TargetFrequency

Setting that controls the average number of times the ads will show to the same person over a certain period of time. Corresponds to the JSON property targetFrequency



11465
11466
11467
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11465

def target_frequency
  @target_frequency
end

#third_party_measurement_settingsGoogle::Apis::DisplayvideoV2::YoutubeAndPartnersThirdPartyMeasurementSettings

Settings that control what third-party vendors are measuring specific line item metrics. Corresponds to the JSON property thirdPartyMeasurementSettings



11471
11472
11473
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11471

def third_party_measurement_settings
  @third_party_measurement_settings
end

#video_ad_inventory_controlGoogle::Apis::DisplayvideoV2::VideoAdInventoryControl

The video ad inventory control used in certain YouTube line item types. Corresponds to the JSON property videoAdInventoryControl



11476
11477
11478
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11476

def video_ad_inventory_control
  @video_ad_inventory_control
end

#video_ad_sequence_settingsGoogle::Apis::DisplayvideoV2::VideoAdSequenceSettings

Settings related to VideoAdSequence. Corresponds to the JSON property videoAdSequenceSettings



11481
11482
11483
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11481

def video_ad_sequence_settings
  @video_ad_sequence_settings
end

#view_frequency_capGoogle::Apis::DisplayvideoV2::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property viewFrequencyCap



11487
11488
11489
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11487

def view_frequency_cap
  @view_frequency_cap
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11494
11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
# File 'lib/google/apis/displayvideo_v2/classes.rb', line 11494

def update!(**args)
  @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy)
  @content_category = args[:content_category] if args.key?(:content_category)
  @effective_content_category = args[:effective_content_category] if args.key?(:effective_content_category)
  @inventory_source_settings = args[:inventory_source_settings] if args.key?(:inventory_source_settings)
  @lead_form_id = args[:lead_form_id] if args.key?(:lead_form_id)
  @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id)
  @related_video_ids = args[:related_video_ids] if args.key?(:related_video_ids)
  @target_frequency = args[:target_frequency] if args.key?(:target_frequency)
  @third_party_measurement_settings = args[:third_party_measurement_settings] if args.key?(:third_party_measurement_settings)
  @video_ad_inventory_control = args[:video_ad_inventory_control] if args.key?(:video_ad_inventory_control)
  @video_ad_sequence_settings = args[:video_ad_sequence_settings] if args.key?(:video_ad_sequence_settings)
  @view_frequency_cap = args[:view_frequency_cap] if args.key?(:view_frequency_cap)
end